#[non_exhaustive]pub enum ConfigSource {
DynamicTopicConfig,
DynamicBrokerLoggerConfig,
DynamicBrokerConfig,
DynamicDefaultBrokerConfig,
DynamicClientMetricsConfig,
DynamicGroupConfig,
StaticBrokerConfig,
DefaultConfig,
Unknown,
}Expand description
Source of configuration entries.
Corresponds to ConfigEntry.ConfigSource.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DynamicTopicConfig
Dynamic topic config that is configured for a specific topic.
DynamicBrokerLoggerConfig
Dynamic broker logger config that is configured for a specific broker.
DynamicBrokerConfig
Dynamic broker config that is configured for a specific broker.
DynamicDefaultBrokerConfig
Dynamic broker config that is configured as default for all brokers in the cluster.
DynamicClientMetricsConfig
Dynamic client metrics subscription config that is configured for all clients.
DynamicGroupConfig
Dynamic group config that is configured for a specific group.
StaticBrokerConfig
Static broker config provided as broker properties at start up (e.g.
server.properties file).
DefaultConfig
Built-in default configuration for configs that have a default value.
Unknown
Source unknown, e.g. in the ConfigEntry used for alter requests where
source is not set.