pub struct CreateTopicsResult { /* private fields */ }Expand description
The result of Admin::create_topics.
Corresponds to org.apache.kafka.clients.admin.CreateTopicsResult.
Implementations
Sourceimpl CreateTopicsResult
impl CreateTopicsResult
Sourcepub fn values(&self) -> HashMap<String, KafkaFuture<()>>
pub fn values(&self) -> HashMap<String, KafkaFuture<()>>
Return a map from topic names to futures, which can be used to check the status of individual topic creations.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds if all the topic creations succeed.
Sourcepub fn config(&self, topic: &str) -> KafkaFuture<Config>
pub fn config(&self, topic: &str) -> KafkaFuture<Config>
Returns a future that provides topic configs for the topic when the request completes.
Panics
Panics if topic was not part of the original request.
Sourcepub fn topic_id(&self, topic: &str) -> KafkaFuture<Uuid>
pub fn topic_id(&self, topic: &str) -> KafkaFuture<Uuid>
Returns a future that provides the topic id for the topic.
Panics
Panics if topic was not part of the original request.
Sourcepub fn num_partitions(&self, topic: &str) -> KafkaFuture<i32>
pub fn num_partitions(&self, topic: &str) -> KafkaFuture<i32>
Returns a future that provides the number of partitions for the topic.
Panics
Panics if topic was not part of the original request.
Sourcepub fn replication_factor(&self, topic: &str) -> KafkaFuture<i32>
pub fn replication_factor(&self, topic: &str) -> KafkaFuture<i32>
Returns a future that provides the replication factor for the topic.
Panics
Panics if topic was not part of the original request.