DeleteAclsResult

Struct DeleteAclsResult 

pub struct DeleteAclsResult { /* private fields */ }
The result of the Admin::delete_acls call.

Corresponds to org.apache.kafka.clients.admin.DeleteAclsResult.

Implementations

Source

impl DeleteAclsResult

pub fn values(&self) -> &HashMap<AclBindingFilter, KafkaFuture<FilterResults>>

Return a map from ACL filters to futures which can be used to check the status of the deletions by each filter.

pub fn all(&self) -> KafkaFuture<Vec<AclBinding>>

Return a future which succeeds only if all the ACL deletions succeed, and which contains all the deleted ACLs. Note that if the filters don’t match any ACLs, this is not considered an error.

Mirrors DeleteAclsResult.all / DeleteAclsResult.getAclBindings.