DescribeProducersResult

Struct DescribeProducersResult 

pub struct DescribeProducersResult { /* private fields */ }
The result of Admin::describe_producers.

Corresponds to org.apache.kafka.clients.admin.DescribeProducersResult.

Implementations

Source

impl DescribeProducersResult

pub fn partition_result( &self, partition: &TopicPartition, ) -> Result<KafkaFuture<PartitionProducerState>, Error>

Returns the future for a specific partition.

Mirrors DescribeProducersResult.partitionResult. Returns an error if the partition was not included in the request, mirroring Java’s IllegalArgumentException.

Errors

Returns Error::local_illegal_argument if partition was not requested.

pub fn all( &self, ) -> KafkaFuture<HashMap<TopicPartition, PartitionProducerState>>

Returns a future yielding a map of every requested partition’s producer state. Fails if any partition’s request fails.

Mirrors DescribeProducersResult.all.