#[non_exhaustive]pub enum DeleteTopicsResult {
ByTopicId(HashMap<Uuid, KafkaFuture<()>>),
ByTopicName(HashMap<String, KafkaFuture<()>>),
}Expand description
The result of Admin::delete_topics.
Corresponds to org.apache.kafka.clients.admin.DeleteTopicsResult. Java
carries two nullable maps and rejects both-null / both-set in the
constructor; the Rust port makes the “exactly one keying” invariant a closed
enum so it is unrepresentable to have both or neither.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
ByTopicId(HashMap<Uuid, KafkaFuture<()>>)
Result keyed by topic id (the request used a TopicIdCollection).
ByTopicName(HashMap<String, KafkaFuture<()>>)
Result keyed by topic name (the request used a TopicNameCollection).
Implementations
Sourceimpl DeleteTopicsResult
impl DeleteTopicsResult
Sourcepub fn topic_id_values(&self) -> Option<&HashMap<Uuid, KafkaFuture<()>>>
pub fn topic_id_values(&self) -> Option<&HashMap<Uuid, KafkaFuture<()>>>
A map from topic IDs to futures if the deletion used topic IDs, otherwise
None.
Sourcepub fn topic_name_values(&self) -> Option<&HashMap<String, KafkaFuture<()>>>
pub fn topic_name_values(&self) -> Option<&HashMap<String, KafkaFuture<()>>>
A map from topic names to futures if the deletion used topic names,
otherwise None.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
A future which succeeds only if all the topic deletions succeed.