DescribeTopicsResult

Enum DescribeTopicsResult 

#[non_exhaustive]
pub enum DescribeTopicsResult { ByTopicId(HashMap<Uuid, KafkaFuture<TopicDescription>>), ByTopicName(HashMap<String, KafkaFuture<TopicDescription>>), }
The result of Admin::describe_topics_with_topics.

Corresponds to org.apache.kafka.clients.admin.DescribeTopicsResult. As with DeleteTopicsResult, the “keyed by id XOR name” invariant is a closed enum instead of Java’s two nullable maps.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ByTopicId(HashMap<Uuid, KafkaFuture<TopicDescription>>)

Result keyed by topic id (the request used a TopicIdCollection).



ByTopicName(HashMap<String, KafkaFuture<TopicDescription>>)

Result keyed by topic name (the request used a TopicNameCollection).

Implementations

Source

impl DescribeTopicsResult

pub fn topic_id_values( &self, ) -> Option<&HashMap<Uuid, KafkaFuture<TopicDescription>>>

A map from topic IDs to futures if the request used topic IDs, otherwise None.

pub fn topic_name_values( &self, ) -> Option<&HashMap<String, KafkaFuture<TopicDescription>>>

A map from topic names to futures if the request used topic names, otherwise None.

pub fn all_topic_names( &self, ) -> Option<KafkaFuture<HashMap<String, TopicDescription>>>

A future map from topic names to descriptions if the request used topic names, otherwise None. Succeeds only if all descriptions succeed.

pub fn all_topic_ids( &self, ) -> Option<KafkaFuture<HashMap<Uuid, TopicDescription>>>

A future map from topic ids to descriptions if the request used topic ids, otherwise None. Succeeds only if all descriptions succeed.