ScramMechanism

Enum ScramMechanism 

#[non_exhaustive]
pub enum ScramMechanism { Unknown, ScramSha256, ScramSha512, }
Representation of a SASL/SCRAM Mechanism.

See KIP-554: Add Broker-side SCRAM Config API.

This code is duplicated in crate::common::security::scram::internals::ScramMechanism. The type field in both files must match and must not change. The type field is used both for passing ScramCredentialUpsertion and for the internal UserScramCredentialRecord. Do not change the type field.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

An unknown / unsupported mechanism (type indicator 0).



ScramSha256

SCRAM-SHA-256 (type indicator 1).



ScramSha512

SCRAM-SHA-512 (type indicator 2).

Implementations

Source

impl ScramMechanism

pub fn from_type(type: i8) -> ScramMechanism

Returns the instance corresponding to the given type indicator, otherwise ScramMechanism::Unknown.

Mirrors ScramMechanism.fromType(byte).

pub fn from_mechanism_name(mechanism_name: &str) -> ScramMechanism

Returns the mechanism corresponding to the SASL SCRAM mechanism name, otherwise ScramMechanism::Unknown.

Mirrors ScramMechanism.fromMechanismName(String).

pub fn mechanism_name(self) -> &'static str

Returns the SASL SCRAM mechanism name (e.g. SCRAM-SHA-256).

Derived from the variant name with _ replaced by -, matching Java’s toString().replace('_', '-').

Mirrors ScramMechanism.mechanismName().

pub fn type(self) -> i8

Returns the type indicator for this SASL SCRAM mechanism.

Mirrors ScramMechanism.type().