FeatureUpdate

Struct FeatureUpdate 

pub struct FeatureUpdate { /* private fields */ }
Encapsulates details about an update to a finalized feature.

Corresponds to org.apache.kafka.clients.admin.FeatureUpdate.

Implementations

Source

impl FeatureUpdate

pub fn new( max_version_level: i16, upgrade_type: UpgradeType, ) -> Result<Self, Error>

Creates a new FeatureUpdate.

max_version_level is the new maximum version level for the finalized feature. A value of zero is special and indicates that the update is intended to delete the finalized feature, and should be accompanied by setting upgrade_type to a safe or unsafe downgrade.

Errors

Returns Error::local_illegal_argument (mirroring Java’s IllegalArgumentException) if max_version_level is zero while upgrade_type is UpgradeType::Upgrade, or if max_version_level is negative.

pub fn max_version_level(&self) -> i16

Returns the new maximum version level for the finalized feature.

pub fn upgrade_type(&self) -> UpgradeType

Returns the upgrade type for this update.