AlterClientQuotasOptions

Struct AlterClientQuotasOptions 

pub struct AlterClientQuotasOptions { /* private fields */ }
Options for Admin::alter_client_quotas.

Corresponds to org.apache.kafka.clients.admin.AlterClientQuotasOptions.

Implementations

Source

impl AlterClientQuotasOptions

pub fn new() -> Self

Creates default options (default API timeout, not validate-only).

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.

pub fn set_validate_only(self, validate_only: bool) -> Self

Sets whether the request should be validated without altering the configs.

Mirrors AlterClientQuotasOptions.validateOnly(boolean).

pub fn validate_only(&self) -> bool

Returns whether the request should be validated without altering the configs.

Mirrors AlterClientQuotasOptions.validateOnly().