pub struct AlterConfigsOptions { /* private fields */ }Expand description
Options for Admin::incremental_alter_configs.
Corresponds to org.apache.kafka.clients.admin.AlterConfigsOptions.
Implementations
Sourceimpl AlterConfigsOptions
impl AlterConfigsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_validate_only(self, validate_only: bool) -> Self
pub fn set_validate_only(self, validate_only: bool) -> Self
Set whether the request should be validated without altering the configs.
Sourcepub fn should_validate_only(&self) -> bool
pub fn should_validate_only(&self) -> bool
Whether the request should be validated without altering the configs.