pub struct AlterPartitionReassignmentsOptions { /* private fields */ }Expand description
Options for Admin::alter_partition_reassignments.
Corresponds to
org.apache.kafka.clients.admin.AlterPartitionReassignmentsOptions.
Implementations
Sourceimpl AlterPartitionReassignmentsOptions
impl AlterPartitionReassignmentsOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (default API timeout, replication-factor change allowed).
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_allow_replication_factor_change(self, allow: bool) -> Self
pub fn set_allow_replication_factor_change(self, allow: bool) -> Self
Set the option indicating if the alter-partition-reassignments call should be allowed to alter the replication factor of a partition.
Mirrors allowReplicationFactorChange(boolean).
Sourcepub fn allow_replication_factor_change(&self) -> bool
pub fn allow_replication_factor_change(&self) -> bool
A boolean indicating if the alter-partition-reassignments should be allowed to alter the replication factor of a partition.
Mirrors allowReplicationFactorChange().