pub struct DeleteAclsOptions { /* private fields */ }Expand description
Options for Admin::delete_acls.
Corresponds to org.apache.kafka.clients.admin.DeleteAclsOptions.
Implementations
Sourceimpl DeleteAclsOptions
impl DeleteAclsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.