pub struct DeleteRecordsOptions { /* private fields */ }Expand description
Options for Admin::delete_records.
Corresponds to org.apache.kafka.clients.admin.DeleteRecordsOptions. In
Java this class only extends AbstractOptions (a timeout_ms field) with
no additional fields.
Implementations
Sourceimpl DeleteRecordsOptions
impl DeleteRecordsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.