pub struct DeleteTopicsOptions { /* private fields */ }Expand description
Options for Admin::delete_topics.
Corresponds to org.apache.kafka.clients.admin.DeleteTopicsOptions.
Implementations
Sourceimpl DeleteTopicsOptions
impl DeleteTopicsOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (retry_on_quota_violation=true, default API
timeout).
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_retry_on_quota_violation(
self,
retry_on_quota_violation: bool,
) -> Self
pub fn set_retry_on_quota_violation( self, retry_on_quota_violation: bool, ) -> Self
Set to true if quota violation should be automatically retried.
Sourcepub fn should_retry_on_quota_violation(&self) -> bool
pub fn should_retry_on_quota_violation(&self) -> bool
Returns true if quota violation should be automatically retried.