DescribeConfigsOptions

Struct DescribeConfigsOptions 

pub struct DescribeConfigsOptions { /* private fields */ }
Options for Admin::describe_configs.

Corresponds to org.apache.kafka.clients.admin.DescribeConfigsOptions.

Implementations

Source

impl DescribeConfigsOptions

pub fn new() -> Self

Creates default options.

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.

pub fn set_include_synonyms(self, include_synonyms: bool) -> Self

Set whether to return configuration synonyms in the response.

pub fn include_synonyms(&self) -> bool

Whether to return configuration synonyms in the response.

pub fn set_include_documentation(self, include_documentation: bool) -> Self

Set whether to return configuration documentation in the response.

pub fn include_documentation(&self) -> bool

Whether to return configuration documentation in the response.