pub struct DescribeFeaturesOptions { /* private fields */ }Expand description
Options for Admin::describe_features.
Corresponds to org.apache.kafka.clients.admin.DescribeFeaturesOptions.
Implementations
Sourceimpl DescribeFeaturesOptions
impl DescribeFeaturesOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_node_id(self, node_id: i32) -> Self
pub fn set_node_id(self, node_id: i32) -> Self
Set the node id to which the request should be sent.
Mirrors DescribeFeaturesOptions.nodeId(int).