pub struct DescribeProducersOptions { /* private fields */ }Expand description
Options for Admin::describe_producers.
Corresponds to org.apache.kafka.clients.admin.DescribeProducersOptions.
When broker_id is set, the request is sent directly to
that broker (via StaticBrokerStrategy) rather than looking up each
partition’s leader.
Implementations
Sourceimpl DescribeProducersOptions
impl DescribeProducersOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_broker_id(self, broker_id: i32) -> Self
pub fn set_broker_id(self, broker_id: i32) -> Self
Set the broker id to query for the topic partitions. Mirrors
DescribeProducersOptions.brokerId(int).