DescribeTopicsOptions

Struct DescribeTopicsOptions 

pub struct DescribeTopicsOptions { /* private fields */ }
Options for Admin::describe_topics_with_topics.

Corresponds to org.apache.kafka.clients.admin.DescribeTopicsOptions.

Implementations

Source

impl DescribeTopicsOptions

pub fn new() -> Self

Creates default options.

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.

pub fn set_include_authorized_operations( self, include_authorized_operations: bool, ) -> Self

Set whether to include authorized operations for the described topics.

pub fn include_authorized_operations(&self) -> bool

Whether to include authorized operations for the described topics.

pub fn set_partition_size_limit_per_response( self, partition_size_limit_per_response: i32, ) -> Self

Sets the maximum number of partitions to be returned in a single response. Only effective when using topic names (not topic IDs), and capped by the server-side max.request.partition.size.limit.

pub fn partition_size_limit_per_response(&self) -> i32

The maximum number of partitions per response.