pub struct ExpireDelegationTokenOptions { /* private fields */ }Expand description
Options for Admin::expire_delegation_token.
Corresponds to
org.apache.kafka.clients.admin.ExpireDelegationTokenOptions.
Implementations
Sourceimpl ExpireDelegationTokenOptions
impl ExpireDelegationTokenOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (default API timeout, expire-immediately
sentinel -1).
Sourcepub fn set_expiry_time_period_ms(self, expiry_time_period_ms: i64) -> Self
pub fn set_expiry_time_period_ms(self, expiry_time_period_ms: i64) -> Self
Sets the time period until the token should expire.
expiry_time_period_ms >= 0: update the expiration timestamp to
min(now + expiry_time_period_ms, max_timestamp). < 0: expire the
token immediately.
Mirrors ExpireDelegationTokenOptions.expiryTimePeriodMs.
Sourcepub fn expiry_time_period_ms(&self) -> i64
pub fn expiry_time_period_ms(&self) -> i64
The time period until the token should expire.
Mirrors ExpireDelegationTokenOptions.expiryTimePeriodMs.
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.