pub struct FenceProducersOptions { /* private fields */ }Expand description
Options for Admin::fence_producers.
Corresponds to org.apache.kafka.clients.admin.FenceProducersOptions. In
Java this class only extends AbstractOptions (a timeout_ms field) with
no additional fields; the timeout doubles as the transaction timeout the
coordinator uses to append the new producer epoch to the transaction log.
Implementations
Sourceimpl FenceProducersOptions
impl FenceProducersOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.