ListConfigResourcesOptions

Struct ListConfigResourcesOptions 

pub struct ListConfigResourcesOptions { /* private fields */ }
Options for Admin::list_config_resources.

Corresponds to org.apache.kafka.clients.admin.ListConfigResourcesOptions.

Implementations

Source

impl ListConfigResourcesOptions

pub fn new() -> Self

Creates default options.

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.