ListOffsetsOptions

Struct ListOffsetsOptions 

pub struct ListOffsetsOptions { /* private fields */ }
Options for Admin::list_offsets.

Corresponds to org.apache.kafka.clients.admin.ListOffsetsOptions, which extends AbstractOptions (a timeout_ms field) and adds an isolation level (defaulting to READ_UNCOMMITTED).

Implementations

Source

impl ListOffsetsOptions

pub fn new() -> Self

Creates default options (default API timeout, READ_UNCOMMITTED).

Mirrors new ListOffsetsOptions().

pub fn with_isolation_level(isolation_level: IsolationLevel) -> Self

Creates options with the given isolation level.

Mirrors new ListOffsetsOptions(IsolationLevel).

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.

pub fn isolation_level(&self) -> IsolationLevel

The isolation level for this operation.

Mirrors isolationLevel().