pub struct ListTopicsOptions { /* private fields */ }Expand description
Options for Admin::list_topics.
Corresponds to org.apache.kafka.clients.admin.ListTopicsOptions.
Implementations
Sourceimpl ListTopicsOptions
impl ListTopicsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_list_internal(self, list_internal: bool) -> Self
pub fn set_list_internal(self, list_internal: bool) -> Self
Set whether we should list internal topics.
Sourcepub fn should_list_internal(&self) -> bool
pub fn should_list_internal(&self) -> bool
Return true if we should list internal topics.