ListTransactionsOptions

Struct ListTransactionsOptions 

pub struct ListTransactionsOptions { /* private fields */ }
Options for Admin::list_transactions.

Corresponds to org.apache.kafka.clients.admin.ListTransactionsOptions.

Implementations

Source

impl ListTransactionsOptions

pub fn new() -> Self

Creates default options: no filters, and filtered_duration_ms == -1 (no duration filtering), matching Java’s defaults.

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.

pub fn filter_states( self, states: impl IntoIterator<Item = TransactionState>, ) -> Self

Filter only the transactions that are in a specific set of states.

Mirrors filterStates.

pub fn filter_producer_ids( self, producer_ids: impl IntoIterator<Item = i64>, ) -> Self

Filter only the transactions from producers in a specific set of producer ids.

Mirrors filterProducerIds.

pub fn filter_on_duration(self, duration_ms: i64) -> Self

Filter only the transactions running longer than the specified duration.

Mirrors filterOnDuration.

pub fn filter_on_transactional_id_pattern(self, pattern: Option<String>) -> Self

Filter only the transactions matching the given transactional id pattern.

Mirrors filterOnTransactionalIdPattern.

pub fn filtered_states(&self) -> &HashSet<TransactionState>

The set of states being filtered (empty means no state filter).

Mirrors filteredStates.

pub fn filtered_producer_ids(&self) -> &HashSet<i64>

The set of producer ids being filtered (empty means no producer id filter).

Mirrors filteredProducerIds.

pub fn filtered_duration(&self) -> i64

The duration filter in milliseconds (negative means no duration filter).

Mirrors filteredDuration.

pub fn filtered_transactional_id_pattern(&self) -> Option<&str>

The transactional id pattern being filtered, if any.

Mirrors filteredTransactionalIdPattern.