RemoveMembersFromConsumerGroupOptions

Struct RemoveMembersFromConsumerGroupOptions 

pub struct RemoveMembersFromConsumerGroupOptions { /* private fields */ }
Options for Admin::remove_members_from_consumer_group. Carries the members to be removed from the consumer group.

Corresponds to org.apache.kafka.clients.admin.RemoveMembersFromConsumerGroupOptions.

Implementations

Source

impl RemoveMembersFromConsumerGroupOptions

pub fn new( members: impl IntoIterator<Item = MemberToRemove>, ) -> Result<Self, Error>

Creates options for removing the given members.

Mirrors Java’s RemoveMembersFromConsumerGroupOptions(Collection<MemberToRemove>).

Errors

Returns an error (Java’s IllegalArgumentException) if members is empty. Use Default::default to remove all members instead.

pub fn set_reason(&mut self, reason: impl Into<String>)

Sets an optional reason.

Mirrors Java’s reason(String).

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the operation timeout in milliseconds (or None for the default).

pub fn members(&self) -> &HashSet<MemberToRemove>

The members to remove.

Mirrors Java’s members().

pub fn reason(&self) -> Option<&str>

The optional reason.

Mirrors Java’s reason().

pub fn remove_all(&self) -> bool

Whether all members should be removed (i.e. no specific members were provided).

Mirrors Java’s removeAll().

pub fn timeout_ms(&self) -> Option<i32>

The operation timeout in milliseconds, or None for the default.