RenewDelegationTokenOptions

Struct RenewDelegationTokenOptions 

pub struct RenewDelegationTokenOptions { /* private fields */ }
Options for Admin::renew_delegation_token.

Corresponds to org.apache.kafka.clients.admin.RenewDelegationTokenOptions.

Implementations

Source

impl RenewDelegationTokenOptions

pub fn new() -> Self

Creates default options (default API timeout, server-default renew period).

pub fn set_renew_time_period_ms(self, renew_time_period_ms: i64) -> Self

Sets the renew time period in milliseconds.

Mirrors RenewDelegationTokenOptions.renewTimePeriodMs.

pub fn renew_time_period_ms(&self) -> i64

The renew time period in milliseconds.

Mirrors RenewDelegationTokenOptions.renewTimePeriodMs.

pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self

Set the timeout in milliseconds for this operation, or None to use the default API timeout for the AdminClient.

pub fn timeout_ms(&self) -> Option<i32>

The timeout in milliseconds for this operation, or None if the default API timeout should be used.