pub struct UpdateFeaturesOptions { /* private fields */ }Expand description
Options for Admin::update_features.
Corresponds to org.apache.kafka.clients.admin.UpdateFeaturesOptions.
Implementations
Sourceimpl UpdateFeaturesOptions
impl UpdateFeaturesOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_validate_only(self, validate_only: bool) -> Self
pub fn set_validate_only(self, validate_only: bool) -> Self
Set whether the request should only be validated, without performing the upgrade or downgrade.
Mirrors UpdateFeaturesOptions.validateOnly(boolean).
Sourcepub fn validate_only(&self) -> bool
pub fn validate_only(&self) -> bool
Whether the request should only be validated.
Mirrors UpdateFeaturesOptions.validateOnly().