pub struct AlterClientQuotasResult { /* private fields */ }Expand description
The result of the Admin::alter_client_quotas call.
Corresponds to org.apache.kafka.clients.admin.AlterClientQuotasResult.
Implementations
Sourceimpl AlterClientQuotasResult
impl AlterClientQuotasResult
Sourcepub fn new(futures: HashMap<ClientQuotaEntity, KafkaFuture<()>>) -> Self
pub fn new(futures: HashMap<ClientQuotaEntity, KafkaFuture<()>>) -> Self
Creates a new result from the per-entity alteration futures.
Sourcepub fn values(&self) -> &HashMap<ClientQuotaEntity, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<ClientQuotaEntity, KafkaFuture<()>>
Returns a map from quota entity to a future which can be used to check the status of the operation.
Mirrors AlterClientQuotasResult.values().
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Returns a future which succeeds only if all quota alterations succeed.
Mirrors AlterClientQuotasResult.all().