pub struct AlterConfigsResult { /* private fields */ }Expand description
The result of the Admin::incremental_alter_configs call.
Corresponds to org.apache.kafka.clients.admin.AlterConfigsResult.
Implementations
Sourceimpl AlterConfigsResult
impl AlterConfigsResult
Sourcepub fn values(&self) -> &HashMap<ConfigResource, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<ConfigResource, KafkaFuture<()>>
Returns a map from resources to futures which can be used to check the status of the alteration for each resource.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Returns a future which succeeds only if all the alteration requests succeed.
Corresponds to AlterConfigsResult.all.