AlterConsumerGroupOffsetsResult

Struct AlterConsumerGroupOffsetsResult 

pub struct AlterConsumerGroupOffsetsResult { /* private fields */ }
The result of Admin::alter_consumer_group_offsets.

Corresponds to org.apache.kafka.clients.admin.AlterConsumerGroupOffsetsResult.

Implementations

Source

impl AlterConsumerGroupOffsetsResult

pub fn partition_result(&self, partition: &TopicPartition) -> KafkaFuture<()>

Returns a future which can be used to check the result for a given partition.

Mirrors partitionResult(TopicPartition). The returned future fails (Java’s IllegalArgumentException) if the partition was not part of the alter request, and otherwise fails with the partition’s error if it was not NONE.

pub fn all(&self) -> KafkaFuture<()>

Returns a future which succeeds if all the alter offsets succeed.

Mirrors all().