pub struct AlterPartitionReassignmentsResult { /* private fields */ }Expand description
The result of Admin::alter_partition_reassignments.
Corresponds to
org.apache.kafka.clients.admin.AlterPartitionReassignmentsResult.
Implementations
Sourceimpl AlterPartitionReassignmentsResult
impl AlterPartitionReassignmentsResult
Sourcepub fn values(&self) -> &HashMap<TopicPartition, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<TopicPartition, KafkaFuture<()>>
Return a map from partitions to futures which can be used to check the status of the reassignment.
Mirrors values().
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds only if all the reassignments were successfully initiated.
Mirrors all().