Config

Struct Config 

pub struct Config { /* private fields */ }
A configuration object containing the configuration entries for a resource.

Corresponds to org.apache.kafka.clients.admin.Config.

Implementations

Source

impl Config

pub fn new(entries: impl IntoIterator<Item = ConfigEntry>) -> Self

Create a configuration instance with the provided entries.

pub fn entries(&self) -> impl Iterator<Item = &ConfigEntry>

Configuration entries for a resource.

pub fn get(&self, name: &str) -> Option<&ConfigEntry>

Get the configuration entry with the provided name or None if there isn’t one.