pub struct CreateAclsResult { /* private fields */ }Expand description
The result of the Admin::create_acls call.
Corresponds to org.apache.kafka.clients.admin.CreateAclsResult.
Implementations
Sourceimpl CreateAclsResult
impl CreateAclsResult
Sourcepub fn values(&self) -> &HashMap<AclBinding, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<AclBinding, KafkaFuture<()>>
Return a map from ACL bindings to futures which can be used to check the status of the creation of each ACL binding.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds only if all the ACL creations succeed.