pub struct CreatePartitionsResult { /* private fields */ }Expand description
The result of Admin::create_partitions.
Corresponds to org.apache.kafka.clients.admin.CreatePartitionsResult.
Implementations
Sourceimpl CreatePartitionsResult
impl CreatePartitionsResult
Sourcepub fn values(&self) -> &HashMap<String, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<String, KafkaFuture<()>>
Return a map from topic names to futures, which can be used to check the status of individual partition creations.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds if all the partition creations succeed.