DeleteConsumerGroupOffsetsResult

Struct DeleteConsumerGroupOffsetsResult 

pub struct DeleteConsumerGroupOffsetsResult { /* private fields */ }
The result of Admin::delete_consumer_group_offsets.

Corresponds to org.apache.kafka.clients.admin.DeleteConsumerGroupOffsetsResult.

Implementations

Source

impl DeleteConsumerGroupOffsetsResult

pub fn partition_result( &self, partition: &TopicPartition, ) -> Result<KafkaFuture<()>, Error>

Returns a future which can be used to check the result for a given partition.

Mirrors partitionResult(TopicPartition).

Errors

Returns an error (Java’s IllegalArgumentException) immediately if the partition was not included in the original request. The returned future fails if the deletion for the partition failed (or the partition is missing from the response).

pub fn all(&self) -> KafkaFuture<()>

Returns a future which succeeds only if all the deletions succeed. If not, the first partition error is returned.

Mirrors all().