pub struct DeleteConsumerGroupsResult { /* private fields */ }Expand description
The result of the Admin::delete_consumer_groups call for a
Collection<String> (group id) input.
Corresponds to org.apache.kafka.clients.admin.DeleteConsumerGroupsResult.
Implementations
Sourceimpl DeleteConsumerGroupsResult
impl DeleteConsumerGroupsResult
Sourcepub fn deleted_groups(&self) -> HashMap<String, KafkaFuture<()>>
pub fn deleted_groups(&self) -> HashMap<String, KafkaFuture<()>>
Returns a map from group id to futures which can be used to check the status of individual deletions.
Mirrors deletedGroups().
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Returns a future which succeeds only if all the consumer group deletions succeed.
Mirrors all().