pub struct DeleteRecordsResult { /* private fields */ }Expand description
The result of Admin::delete_records.
Corresponds to org.apache.kafka.clients.admin.DeleteRecordsResult.
Implementations
Sourceimpl DeleteRecordsResult
impl DeleteRecordsResult
Sourcepub fn low_watermarks(
&self,
) -> &HashMap<TopicPartition, KafkaFuture<DeletedRecords>>
pub fn low_watermarks( &self, ) -> &HashMap<TopicPartition, KafkaFuture<DeletedRecords>>
Return a map from topic partition to futures which can be used to check the status of individual deletions.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds only if all the records deletions succeed.