DeletedRecords

Struct DeletedRecords 

pub struct DeletedRecords { /* private fields */ }
Represents information about deleted records.

Corresponds to org.apache.kafka.clients.admin.DeletedRecords.

Implementations

Source

impl DeletedRecords

pub fn new(low_watermark: i64) -> Self

Create an instance of this class with the provided parameters.

low_watermark is the “low watermark” for the topic partition on which the deletion was executed.

pub fn low_watermark(&self) -> i64

Return the “low watermark” for the topic partition on which the deletion was executed.