pub struct DescribeConfigsResult { /* private fields */ }Expand description
The result of the Admin::describe_configs call.
Corresponds to org.apache.kafka.clients.admin.DescribeConfigsResult.
Implementations
Sourceimpl DescribeConfigsResult
impl DescribeConfigsResult
Sourcepub fn values(&self) -> &HashMap<ConfigResource, KafkaFuture<Config>>
pub fn values(&self) -> &HashMap<ConfigResource, KafkaFuture<Config>>
Returns a map from resources to futures which can be used to check the status of the configuration for each resource.
Sourcepub fn all(&self) -> KafkaFuture<HashMap<ConfigResource, Config>>
pub fn all(&self) -> KafkaFuture<HashMap<ConfigResource, Config>>
Returns a future which succeeds only if all the config descriptions succeed, yielding a map from each resource to its config.
Corresponds to DescribeConfigsResult.all.