DescribeLogDirsResult

Struct DescribeLogDirsResult 

pub struct DescribeLogDirsResult { /* private fields */ }
The result of the Admin::describe_log_dirs call.

Corresponds to org.apache.kafka.clients.admin.DescribeLogDirsResult.

Implementations

Source

impl DescribeLogDirsResult

pub fn descriptions( &self, ) -> &HashMap<i32, KafkaFuture<HashMap<String, LogDirDescription>>>

Returns a map from broker id to a future which can be used to check the information of partitions on each individual broker. The result of the future is a map from broker log directory path to a description of that log directory.

pub fn all_descriptions( &self, ) -> KafkaFuture<HashMap<i32, HashMap<String, LogDirDescription>>>

Returns a future which succeeds only if all the brokers have responded without error, yielding a map from broker id to a map from broker log directory path to a description of that log directory.

Corresponds to DescribeLogDirsResult.allDescriptions.