pub struct ElectLeadersResult { /* private fields */ }Expand description
The result of Admin::elect_leaders.
Corresponds to org.apache.kafka.clients.admin.ElectLeadersResult.
Implementations
Sourceimpl ElectLeadersResult
impl ElectLeadersResult
Sourcepub fn partitions(&self) -> KafkaFuture<HashMap<TopicPartition, Option<Error>>>
pub fn partitions(&self) -> KafkaFuture<HashMap<TopicPartition, Option<Error>>>
Get a future for the topic partitions for which a leader election was
attempted. If the election succeeded then the value for a topic
partition will be None; otherwise the election failed and the value
will be Some(error).
Mirrors partitions().
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds if all the topic elections succeed.
Mirrors all().