FeatureMetadata

Struct FeatureMetadata 

pub struct FeatureMetadata { /* private fields */ }
Encapsulates details about finalized as well as supported features.

This is particularly useful to hold the result returned by the describe_features_with_options API.

Corresponds to org.apache.kafka.clients.admin.FeatureMetadata.

Implementations

Source

impl FeatureMetadata

pub fn finalized_features(&self) -> &HashMap<String, FinalizedVersionRange>

Returns a map of finalized feature versions. Each entry contains a feature name and the range of version levels supported by every broker in the cluster.

pub fn finalized_features_epoch(&self) -> Option<i64>

The epoch for the finalized features. If empty, the finalized features are absent/unavailable.

pub fn supported_features(&self) -> &HashMap<String, SupportedVersionRange>

Returns a map of supported feature versions. Each entry contains a feature name and the range of versions supported by a particular broker in the cluster.