pub struct FenceProducersResult { /* private fields */ }Expand description
The result of Admin::fence_producers.
Corresponds to org.apache.kafka.clients.admin.FenceProducersResult. Java
keys the per-producer futures by CoordinatorKey; since CoordinatorKey is
an internal (pub(crate)) type, the Rust result keys them by the
transactional id string, following the DescribeConsumerGroupsResult
precedent.
Implementations
Sourceimpl FenceProducersResult
impl FenceProducersResult
Sourcepub fn fenced_producers(&self) -> HashMap<String, KafkaFuture<()>>
pub fn fenced_producers(&self) -> HashMap<String, KafkaFuture<()>>
Return a map from transactional id to futures which can be used to check the status of individual fencings.
Mirrors FenceProducersResult.fencedProducers.
Sourcepub fn producer_id(
&self,
transactional_id: &str,
) -> Result<KafkaFuture<i64>, Error>
pub fn producer_id( &self, transactional_id: &str, ) -> Result<KafkaFuture<i64>, Error>
Returns a future that provides the producer id generated while initializing the given transaction when the request completes.
Mirrors FenceProducersResult.producerId.
Errors
Returns Error::local_illegal_argument if transactional_id was not
included in the request.
Sourcepub fn epoch_id(
&self,
transactional_id: &str,
) -> Result<KafkaFuture<i16>, Error>
pub fn epoch_id( &self, transactional_id: &str, ) -> Result<KafkaFuture<i16>, Error>
Returns a future that provides the epoch generated while initializing the given transaction when the request completes.
Mirrors FenceProducersResult.epochId.
Errors
Returns Error::local_illegal_argument if transactional_id was not
included in the request.
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds only if all the producer fencings succeed.
Mirrors FenceProducersResult.all.