ListConsumerGroupOffsetsResult

Struct ListConsumerGroupOffsetsResult 

pub struct ListConsumerGroupOffsetsResult { /* private fields */ }
The result of Admin::list_consumer_group_offsets_with_group_specs.

Corresponds to org.apache.kafka.clients.admin.ListConsumerGroupOffsetsResult.

Implementations

Source

impl ListConsumerGroupOffsetsResult

pub fn partitions_to_offset_and_metadata( &self, ) -> Result<KafkaFuture<GroupOffsets>, Error>

Returns a future which yields a map of topic partitions to OffsetAndMetadata for the single requested group. A None value indicates the group has no committed offset for that partition.

Mirrors partitionsToOffsetAndMetadata().

Errors

Returns an error (Java’s IllegalStateException) if offsets from multiple groups were requested — use partitions_to_offset_and_metadata_for_group instead.

pub fn partitions_to_offset_and_metadata_for_group( &self, group_id: &str, ) -> Result<KafkaFuture<GroupOffsets>, Error>

Returns a future which yields a map of topic partitions to OffsetAndMetadata for the specified group. A None value indicates the group has no committed offset for that partition.

Mirrors partitionsToOffsetAndMetadata(String groupId).

Errors

Returns an error (Java’s IllegalArgumentException) if offsets for the given group were not requested.

pub fn all(&self) -> KafkaFuture<HashMap<String, GroupOffsets>>

Returns a future which yields all group offsets, if requests for all the groups succeed.

Mirrors all().