pub struct ListTopicsResult { /* private fields */ }Expand description
The result of Admin::list_topics.
Corresponds to org.apache.kafka.clients.admin.ListTopicsResult.
Implementations
Sourceimpl ListTopicsResult
impl ListTopicsResult
Sourcepub fn names_to_listings(&self) -> KafkaFuture<HashMap<String, TopicListing>>
pub fn names_to_listings(&self) -> KafkaFuture<HashMap<String, TopicListing>>
Return a future which yields a map of topic names to TopicListing
objects.
Sourcepub fn listings(&self) -> KafkaFuture<Vec<TopicListing>>
pub fn listings(&self) -> KafkaFuture<Vec<TopicListing>>
Return a future which yields a collection of TopicListing objects.
Sourcepub fn names(&self) -> KafkaFuture<HashSet<String>>
pub fn names(&self) -> KafkaFuture<HashSet<String>>
Return a future which yields a set of topic names.