ListTransactionsResult

Struct ListTransactionsResult 

pub struct ListTransactionsResult { /* private fields */ }
The result of Admin::list_transactions.

Corresponds to org.apache.kafka.clients.admin.ListTransactionsResult. The wrapped future completes when the broker list is discovered, yielding a map from broker id to that broker’s per-request future (mirroring Java’s KafkaFuture<Map<Integer, KafkaFutureImpl<Collection<TransactionListing>>>>).

Implementations

Source

impl ListTransactionsResult

pub fn all(&self) -> KafkaFuture<Vec<TransactionListing>>

Get all transaction listings. If any of the underlying requests fail, the returned future also fails with the first encountered error.

Mirrors ListTransactionsResult.all.

pub fn by_broker_id( &self, ) -> KafkaFuture<HashMap<i32, KafkaFuture<Vec<TransactionListing>>>>

Get a future returning the per-broker listing futures. Useful for a partial listing or more granular error details.

Mirrors ListTransactionsResult.byBrokerId.

pub fn all_by_broker_id( &self, ) -> KafkaFuture<HashMap<i32, Vec<TransactionListing>>>

Get all transaction listings keyed by the broker id currently managing them. If any underlying request fails, the returned future also fails.

Mirrors ListTransactionsResult.allByBrokerId.