NewPartitions

Struct NewPartitions 

pub struct NewPartitions { /* private fields */ }
Describes new partitions for a particular topic in a call to Admin::create_partitions.

Corresponds to org.apache.kafka.clients.admin.NewPartitions.

Implementations

Source

impl NewPartitions

pub fn increase_to(total_count: i32) -> Self

Increase the partition count for a topic to the given total_count. The assignment of new replicas to brokers will be decided by the broker.

total_count is the total number of partitions after the operation succeeds.

pub fn increase_to_new_assignments( total_count: i32, new_assignments: Vec<Vec<i32>>, ) -> Self

Increase the partition count for a topic to the given total_count assigning the new partitions according to the given new_assignments.

The length of the given new_assignments should equal total_count - old_count, since the assignment of existing partitions is not changed. Each inner list of new_assignments should have a length equal to the topic’s replication factor. The first broker id in each inner list is the “preferred replica”.

total_count is the total number of partitions after the operation succeeds; new_assignments are the replica assignments for the new partitions.

pub fn total_count(&self) -> i32

The total number of partitions after the operation succeeds.

pub fn assignments(&self) -> Option<&Vec<Vec<i32>>>

The replica assignments for the new partitions, or None if the assignment will be done by the controller.