pub struct ProducerState { /* private fields */ }Expand description
The state of an active producer for a partition.
Corresponds to org.apache.kafka.clients.admin.ProducerState. producer_id
and last_timestamp are i64 (Java long); coordinator_epoch and
current_transaction_start_offset are optional (Java OptionalInt /
OptionalLong).
Implementations
Sourceimpl ProducerState
impl ProducerState
Sourcepub fn new(
producer_id: i64,
producer_epoch: i32,
last_sequence: i32,
last_timestamp: i64,
coordinator_epoch: Option<i32>,
current_transaction_start_offset: Option<i64>,
) -> Self
pub fn new( producer_id: i64, producer_epoch: i32, last_sequence: i32, last_timestamp: i64, coordinator_epoch: Option<i32>, current_transaction_start_offset: Option<i64>, ) -> Self
Creates a new ProducerState.
Sourcepub fn producer_id(&self) -> i64
pub fn producer_id(&self) -> i64
The producer id.
Sourcepub fn producer_epoch(&self) -> i32
pub fn producer_epoch(&self) -> i32
The producer epoch.
Sourcepub fn last_sequence(&self) -> i32
pub fn last_sequence(&self) -> i32
The last sequence number written by this producer.
Sourcepub fn last_timestamp(&self) -> i64
pub fn last_timestamp(&self) -> i64
The last timestamp written by this producer.
Sourcepub fn current_transaction_start_offset(&self) -> Option<i64>
pub fn current_transaction_start_offset(&self) -> Option<i64>
The offset of the first record in the current transaction, if any.
Sourcepub fn coordinator_epoch(&self) -> Option<i32>
pub fn coordinator_epoch(&self) -> Option<i32>
The coordinator epoch, if any.