ReplicaInfo

Struct ReplicaInfo 

pub struct ReplicaInfo { /* private fields */ }
A description of a replica on a particular broker.

Corresponds to org.apache.kafka.clients.admin.ReplicaInfo.

Implementations

Source

impl ReplicaInfo

pub fn new(size: i64, offset_lag: i64, is_future: bool) -> Self

Creates a new ReplicaInfo.

pub fn size(&self) -> i64

The total size of the log segments in this replica in bytes.

This value does not include the size of data stored in remote storage.

pub fn offset_lag(&self) -> i64

The lag of the log’s LEO with respect to the partition’s high watermark (if it is the current log for the partition) or the current replica’s LEO (if it is the future log for the partition).

pub fn is_future(&self) -> bool

Whether this replica has been created by an AlterReplicaLogDirsRequest but has not yet replaced the current replica on the broker.