pub struct ScramCredentialInfo { /* private fields */ }Expand description
Mechanism and iterations for a SASL/SCRAM credential associated with a user.
Implementations
Sourceimpl ScramCredentialInfo
impl ScramCredentialInfo
Sourcepub fn new(mechanism: ScramMechanism, iterations: i32) -> Self
pub fn new(mechanism: ScramMechanism, iterations: i32) -> Self
Creates a new credential info.
mechanism— the required mechanismiterations— the number of iterations used when creating the credential
Sourcepub fn mechanism(&self) -> ScramMechanism
pub fn mechanism(&self) -> ScramMechanism
Returns the mechanism.
Sourcepub fn iterations(&self) -> i32
pub fn iterations(&self) -> i32
Returns the number of iterations used when creating the credential.