pub struct UpdateFeaturesResult { /* private fields */ }Expand description
The result of the update_features_with_options
call.
Corresponds to org.apache.kafka.clients.admin.UpdateFeaturesResult.
Implementations
Sourceimpl UpdateFeaturesResult
impl UpdateFeaturesResult
Sourcepub fn values(&self) -> &HashMap<String, KafkaFuture<()>>
pub fn values(&self) -> &HashMap<String, KafkaFuture<()>>
Return a map from feature name to future, which can be used to check the status of individual feature updates.
Mirrors values().
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Return a future which succeeds if all the feature updates succeed.
Mirrors all().