pub struct UserScramCredentialUpsertion { /* private fields */ }Expand description
A request to update/insert a SASL/SCRAM credential for a user.
Implementations
Sourceimpl UserScramCredentialUpsertion
impl UserScramCredentialUpsertion
Sourcepub fn with_str(
user: impl Into<String>,
credential_info: ScramCredentialInfo,
password: &str,
) -> Self
pub fn with_str( user: impl Into<String>, credential_info: ScramCredentialInfo, password: &str, ) -> Self
Constructor that accepts a string password and generates a random salt.
Mirrors UserScramCredentialUpsertion(String, ScramCredentialInfo, String),
which encodes the password with UTF-8.
Sourcepub fn with_bytes(
user: impl Into<String>,
credential_info: ScramCredentialInfo,
password: Vec<u8>,
) -> Self
pub fn with_bytes( user: impl Into<String>, credential_info: ScramCredentialInfo, password: Vec<u8>, ) -> Self
Constructor that accepts a byte password and generates a random salt.
Mirrors UserScramCredentialUpsertion(String, ScramCredentialInfo, byte[]).
Sourcepub fn with_salt(
user: impl Into<String>,
credential_info: ScramCredentialInfo,
password: Vec<u8>,
salt: Vec<u8>,
) -> Self
pub fn with_salt( user: impl Into<String>, credential_info: ScramCredentialInfo, password: Vec<u8>, salt: Vec<u8>, ) -> Self
Constructor that accepts an explicit salt.
Mirrors UserScramCredentialUpsertion(String, ScramCredentialInfo, byte[], byte[]).
Sourcepub fn credential_info(&self) -> &ScramCredentialInfo
pub fn credential_info(&self) -> &ScramCredentialInfo
Returns the mechanism and iterations.