AclOperation

Enum AclOperation 

#[non_exhaustive]
pub enum AclOperation {
Show 16 variants Unknown, Any, All, Read, Write, Create, Delete, Alter, Describe, ClusterAction, DescribeConfigs, AlterConfigs, IdempotentWrite, CreateTokens, DescribeTokens, TwoPhaseCommit,
}
Represents an operation which an ACL grants or denies permission to perform.

Some operations imply other operations:

  • ALLOW ALL implies ALLOW everything
  • DENY ALL implies DENY everything
  • ALLOW READ implies ALLOW DESCRIBE
  • ALLOW WRITE implies ALLOW DESCRIBE
  • ALLOW DELETE implies ALLOW DESCRIBE
  • ALLOW ALTER implies ALLOW DESCRIBE
  • ALLOW ALTER_CONFIGS implies ALLOW DESCRIBE_CONFIGS

Corresponds to org.apache.kafka.common.acl.AclOperation.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Unknown

Represents any AclOperation which this client cannot understand, perhaps because this client is too old.



Any

In a filter, matches any AclOperation.



All

ALL operation.



Read

READ operation.



Write

WRITE operation.



Create

CREATE operation.



Delete

DELETE operation.



Alter

ALTER operation.



Describe

DESCRIBE operation.



ClusterAction

CLUSTER_ACTION operation.



DescribeConfigs

DESCRIBE_CONFIGS operation.



AlterConfigs

ALTER_CONFIGS operation.



IdempotentWrite

IDEMPOTENT_WRITE operation.



CreateTokens

CREATE_TOKENS operation.



DescribeTokens

DESCRIBE_TOKENS operation.



TwoPhaseCommit

TWO_PHASE_COMMIT operation.

Implementations

Source

impl AclOperation

pub fn code(&self) -> i8

Return the code of this operation.

pub fn from_code(code: i8) -> AclOperation

Return the AclOperation with the provided code or AclOperation::Unknown if one cannot be found.

pub fn from_string(str: &str) -> AclOperation

Parse the given string as an ACL operation.

Returns the AclOperation, or AclOperation::Unknown if the string could not be matched (case-insensitive).

pub fn is_unknown(&self) -> bool

Return true if this operation is AclOperation::Unknown.