AccessControlEntry

Struct AccessControlEntry 

pub struct AccessControlEntry { /* private fields */ }
Represents an access control entry. ACEs are a tuple of principal, host, operation, and permissionType.

Corresponds to org.apache.kafka.common.acl.AccessControlEntry.

Implementations

Source

impl AccessControlEntry

pub fn new( principal: impl Into<String>, host: impl Into<String>, operation: AclOperation, permission_type: AclPermissionType, ) -> Result<AccessControlEntry, Error>

Create an instance of an access control entry with the provided parameters.

Arguments
  • principal - principal
  • host - host
  • operation - operation, ANY is not an allowed operation
  • permission_type - permission type, ANY is not an allowed type
Errors

Returns Error::LocalIllegalArgument if operation is AclOperation::Any or permission_type is AclPermissionType::Any (mirrors Java’s IllegalArgumentException).

pub fn principal(&self) -> &str

Return the principal for this entry.

pub fn host(&self) -> &str

Return the host, or * for all hosts.

pub fn operation(&self) -> AclOperation

Return the AclOperation. This method will never return AclOperation::Any.

pub fn permission_type(&self) -> AclPermissionType

Return the AclPermissionType. This method will never return AclPermissionType::Any.

pub fn to_filter(&self) -> AccessControlEntryFilter

Create a filter which matches only this AccessControlEntry.

pub fn is_unknown(&self) -> bool

Return true if this ACE has any UNKNOWN components.