AclBinding

Struct AclBinding 

pub struct AclBinding { /* private fields */ }
Represents a binding between a resource pattern and an access control entry.

Corresponds to org.apache.kafka.common.acl.AclBinding.

Implementations

Source

impl AclBinding

pub fn new(pattern: ResourcePattern, entry: AccessControlEntry) -> AclBinding

Create an instance of this class with the provided parameters.

Arguments
  • pattern - resource pattern
  • entry - entry
pub fn is_unknown(&self) -> bool

Return true if this binding has any UNKNOWN components.

pub fn pattern(&self) -> &ResourcePattern

Return the resource pattern for this binding.

pub fn entry(&self) -> &AccessControlEntry

Return the access control entry for this binding.

pub fn to_filter(&self) -> AclBindingFilter

Create a filter which matches only this AclBinding.