pub struct ConfigResource { /* private fields */ }Expand description
A class representing resources that have configs.
Corresponds to org.apache.kafka.common.config.ConfigResource.
Implementations
Sourceimpl ConfigResource
impl ConfigResource
Sourcepub fn new(resource_type: Type, name: String) -> Self
pub fn new(resource_type: Type, name: String) -> Self
Create an instance of this class with the provided parameters.
resource_type- a resource typename- a resource name
Sourcepub fn resource_type(&self) -> Type
pub fn resource_type(&self) -> Type
Return the resource type.
Sourcepub fn is_default(&self) -> bool
pub fn is_default(&self) -> bool
Returns true if this is the default resource of a resource type. Resource name is empty for the default resource.