SslClientAuth

Enum SslClientAuth 

#[non_exhaustive]
pub enum SslClientAuth { Required, Requested, None, }
Whether the server requires or requests client TLS authentication.

This is primarily a server-side setting, but included for config compatibility with Java’s SslClientAuth.

Translated from org.apache.kafka.common.config.SslClientAuth.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Required

Server requires client certificate.



Requested

Server requests but does not require client certificate.



None

Server does not request client certificate.

Implementations

Source

impl SslClientAuth

pub fn for_config(key: Option<&str>) -> Option<Self>

Case-insensitive lookup by config string.

Returns SslClientAuth::None if key is None. Returns None if key is Some but does not match any variant.

Matches Java’s SslClientAuth.forConfig(String) behavior:

  • null maps to NONE
  • Unknown string returns null (here: Option::None)