IsolationLevel

Enum IsolationLevel 

#[non_exhaustive]
pub enum IsolationLevel { ReadUncommitted, ReadCommitted, }
Isolation level used to control which records are visible to a consumer when reading from a topic.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


ReadUncommitted

Read records including those from in-flight (uncommitted) transactions.



ReadCommitted

Skip records from in-flight (uncommitted) transactions and only read records up to the last stable offset.

Implementations

Source

impl IsolationLevel

pub fn id(&self) -> u8

Returns the wire-protocol id used to encode this isolation level.

Translated from Java’s byte id().

pub fn for_id(id: u8) -> Result<Self, Error>

Returns the IsolationLevel for the given wire-protocol id.

Translated from Java’s forId(byte id). Returns Error::LocalIllegalArgument for unknown ids; the Java implementation throws IllegalArgumentException.