pub struct WindowedCount { /* private fields */ }Expand description
A SampledStat that maintains a simple count of what it has seen. This is
a special kind of crate::common::metrics::stats::WindowedSum that always
records a value of 1 instead of the provided value. In other words, it
counts the number of record invocations, instead of summing the recorded
values.
See also crate::common::metrics::stats::CumulativeCount for a non-sampled
version of this metric.
Implementations
Sourceimpl WindowedCount
impl WindowedCount