pub struct Quota { /* private fields */ }Expand description
An upper or lower bound for metrics.
Implementations
Sourceimpl Quota
impl Quota
Sourcepub fn new(bound: f64, upper: bool) -> Self
pub fn new(bound: f64, upper: bool) -> Self
Create a quota with the given bound and whether it is an upper bound.
Sourcepub fn upper_bound(upper_bound: f64) -> Self
pub fn upper_bound(upper_bound: f64) -> Self
Create an upper-bound quota.
Sourcepub fn lower_bound(lower_bound: f64) -> Self
pub fn lower_bound(lower_bound: f64) -> Self
Create a lower-bound quota.
Sourcepub fn is_upper_bound(&self) -> bool
pub fn is_upper_bound(&self) -> bool
Whether this quota is an upper bound.
Sourcepub fn acceptable(&self, value: f64) -> bool
pub fn acceptable(&self, value: f64) -> bool
Whether the given value is acceptable under this quota.