CompoundStat

Trait CompoundStat 

pub trait CompoundStat: Stat {
    // Required method
    fn stats(&self) -> Vec<NamedMeasurable>;
}
A compound stat is a stat where a single measurement and associated data structure feeds many metrics. This is the example for a histogram which has many associated percentiles.

Required Methods

fn stats(&self) -> Vec<NamedMeasurable>

The named measurable child metrics this compound stat exposes.

Implementors