MeasurableStat

Trait MeasurableStat 

pub trait MeasurableStat: Stat + Measurable { }
A MeasurableStat is a Stat that is also Measurable (i.e. can produce a single floating point value). This is the interface used for most of the simple statistics such as Avg, Max, CumulativeCount, etc.

Implementors