ClientQuotaEntity

Struct ClientQuotaEntity 

pub struct ClientQuotaEntity { /* private fields */ }
Describes a client quota entity, which is a mapping of entity types to their names.

Corresponds to org.apache.kafka.common.quota.ClientQuotaEntity.

Java models the mapping as a Map<String, String> whose values may be null: “If a name is null, then it is mapped to the built-in default entity name” (e.g. --entity-type users --entity-default). Rust cannot store a null String, so the faithful representation of Java’s nullable map value is Option<String>: None is the built-in default entity (wire-null entity name), and Some(name) is a concretely-named entity (Some(String::new()) is the entity literally named "", which is distinct from the default).

Implementations

Source

impl ClientQuotaEntity

pub const USER: &str = "user"

The entity type value for a user.

pub const CLIENT_ID: &str = "client-id"

The entity type value for a client id.

pub const IP: &str = "ip"

The entity type value for an IP address.

pub fn is_valid_entity_type(entity_type: &str) -> bool

Returns whether the given entity type is one of the built-in types.

Mirrors ClientQuotaEntity.isValidEntityType.

pub fn new(entries: HashMap<String, Option<String>>) -> Self

Constructs a quota entity for the given types and names. If a name is None (Java null), then it is mapped to the built-in default entity name.

Mirrors ClientQuotaEntity(Map<String, String>).

pub fn entries(&self) -> &HashMap<String, Option<String>>

Returns the map of entity type to its name. A None value denotes the built-in default entity (Java’s null name).

Mirrors ClientQuotaEntity.entries().