pub struct Resource { /* private fields */ }Expand description
Represents a cluster resource with a tuple of (type, name).
Corresponds to org.apache.kafka.common.resource.Resource.
Implementations
Sourceimpl Resource
impl Resource
Sourcepub const CLUSTER_NAME: &str = "kafka-cluster"
pub const CLUSTER_NAME: &str = "kafka-cluster"
The name of the CLUSTER resource.
Sourcepub fn new(resource_type: ResourceType, name: impl Into<String>) -> Resource
pub fn new(resource_type: ResourceType, name: impl Into<String>) -> Resource
Create an instance of this class with the provided parameters.
Arguments
resource_type- resource typename- resource name
Sourcepub fn resource_type(&self) -> ResourceType
pub fn resource_type(&self) -> ResourceType
Return the resource type.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Return true if this Resource has any UNKNOWN components.