ResourcePattern

Struct ResourcePattern 

pub struct ResourcePattern { /* private fields */ }
Represents a pattern that is used by ACLs to match zero or more Resources.

Corresponds to org.apache.kafka.common.resource.ResourcePattern.

Implementations

Source

impl ResourcePattern

pub const WILDCARD_RESOURCE: &str = "*"

A special literal resource name that corresponds to ‘all resources of a certain type’.

pub fn new( resource_type: ResourceType, name: impl Into<String>, pattern_type: PatternType, ) -> Result<ResourcePattern, Error>

Create a pattern using the supplied parameters.

Arguments
  • resource_type - specific resource type
  • name - resource name, which can be the Self::WILDCARD_RESOURCE
  • pattern_type - specific resource pattern type, which controls how the pattern will match resource names
Errors

Returns Error::LocalIllegalArgument if resource_type is ResourceType::Any, or pattern_type is PatternType::Match or PatternType::Any (mirrors Java’s IllegalArgumentException).

pub fn resource_type(&self) -> ResourceType

Return the specific resource type this pattern matches.

pub fn name(&self) -> &str

Return the resource name.

pub fn pattern_type(&self) -> PatternType

Return the resource pattern type.

pub fn to_filter(&self) -> ResourcePatternFilter

Return a filter which matches only this pattern.

pub fn is_unknown(&self) -> bool

Return true if this pattern has any UNKNOWN components.