KafkaPrincipal

Struct KafkaPrincipal 

pub struct KafkaPrincipal { /* private fields */ }
Principals in Kafka are defined by a type and a name.

The principal type will always be "User" for the simple authorizer that is enabled by default, but custom authorizers can leverage different principal types (such as to enable group or role-based ACLs).

Corresponds to org.apache.kafka.common.security.auth.KafkaPrincipal.

Implementations

Source

impl KafkaPrincipal

pub const USER_TYPE: &'static str = "User"

The principal type used by the default authorizer.

pub fn new(principal_type: impl Into<String>, name: impl Into<String>) -> Self

Creates a new principal from a type and name (not token-authenticated).

Mirrors new KafkaPrincipal(principalType, name).

pub fn with_token_authenticated( principal_type: impl Into<String>, name: impl Into<String>, token_authenticated: bool, ) -> Self

Creates a new principal from a type, name, and token-authenticated flag.

Mirrors new KafkaPrincipal(principalType, name, tokenAuthenticated).

pub fn anonymous() -> Self

The anonymous principal (User:ANONYMOUS).

Mirrors KafkaPrincipal.ANONYMOUS. Modeled as a function rather than a constant because the name is an owned String.

pub fn name(&self) -> &str

Returns the principal name.

Mirrors KafkaPrincipal.getName.

pub fn principal_type(&self) -> &str

Returns the principal type.

Mirrors KafkaPrincipal.getPrincipalType.

pub fn set_token_authenticated(&mut self, token_authenticated: bool)

Sets whether the principal was authenticated with a delegation token.

Mirrors KafkaPrincipal.tokenAuthenticated(boolean).

pub fn token_authenticated(&self) -> bool

Whether the principal was authenticated with a delegation token.

Mirrors KafkaPrincipal.tokenAuthenticated().