Cluster

Struct Cluster 

pub struct Cluster { /* private fields */ }
An immutable representation of a subset of the nodes, topics, and partitions in the Kafka cluster.

Implementations

Source

impl Cluster

pub fn new( cluster_id: Option<String>, nodes: Vec<Node>, partitions: Vec<PartitionInfo>, unauthorized_topics: HashSet<String>, internal_topics: HashSet<String>, ) -> Self

Create a new cluster with the given id, nodes and partitions.

Corresponds to Java’s Cluster(String, Collection<Node>, Collection<PartitionInfo>, Set<String>, Set<String>) (Cluster.java:57), whose parameters {clusterId, nodes, partitions, unauthorizedTopics, internalTopics} are the intersection across the four public constructors — so it owns the plain name (CLAUDE.md 2).

Arguments
  • nodes - The nodes in the cluster
  • partitions - Information about a subset of the topic-partitions this cluster hosts
pub fn with_controller( cluster_id: Option<String>, nodes: Vec<Node>, partitions: Vec<PartitionInfo>, unauthorized_topics: HashSet<String>, internal_topics: HashSet<String>, controller: Option<Node>, ) -> Self

Create a new cluster with the given id, nodes, partitions and controller.

Corresponds to Java’s Cluster(String, Collection<Node>, Collection<PartitionInfo>, Set<String>, Set<String>, Node) (Cluster.java:70).

Arguments
  • nodes - The nodes in the cluster
  • partitions - Information about a subset of the topic-partitions this cluster hosts
pub fn with_invalid_topics_controller( cluster_id: Option<String>, nodes: Vec<Node>, partitions: Vec<PartitionInfo>, unauthorized_topics: HashSet<String>, invalid_topics: HashSet<String>, internal_topics: HashSet<String>, controller: Option<Node>, ) -> Self

Create a new cluster with the given id, nodes, partitions, invalid topics and controller.

Corresponds to Java’s Cluster(String, Collection<Node>, Collection<PartitionInfo>, Set<String>, Set<String>, Set<String>, Node) (Cluster.java:84).

Arguments
  • nodes - The nodes in the cluster
  • partitions - Information about a subset of the topic-partitions this cluster hosts
pub fn with_invalid_topics_controller_topic_ids( cluster_id: Option<String>, nodes: Vec<Node>, partitions: Vec<PartitionInfo>, unauthorized_topics: HashSet<String>, invalid_topics: HashSet<String>, internal_topics: HashSet<String>, controller: Option<Node>, topic_ids: HashMap<String, Uuid>, ) -> Self

Create a new cluster with the given id, nodes, partitions and topic ids.

Corresponds to Java’s widest public constructor (Cluster.java:99).

Arguments
  • nodes - The nodes in the cluster
  • partitions - Information about a subset of the topic-partitions this cluster hosts
pub fn empty() -> Self

Create an empty cluster instance with no nodes and no topic-partitions.

pub fn bootstrap(addresses: &[(String, SocketAddr)]) -> Self

Create a “bootstrap” cluster using the given list of (hostname, address) pairs.

pub fn with_partitions( &self, partitions: HashMap<TopicPartition, PartitionInfo>, ) -> Self

Return a copy of this cluster combined with additional partitions.

pub fn nodes(&self) -> &[Node]

The known set of nodes.

pub fn node_by_id(&self, id: i32) -> Option<&Node>

Get the node by the node id (or None if the node is not online or does not exist).

pub fn node_if_online( &self, partition: &TopicPartition, id: i32, ) -> Option<&Node>

Get the node by node id if the replica for the given partition is online.

pub fn leader_for(&self, topic_partition: &TopicPartition) -> Option<&Node>

Get the current leader for the given topic-partition.

pub fn partition( &self, topic_partition: &TopicPartition, ) -> Option<&PartitionInfo>

Get the metadata for the specified partition.

pub fn partitions_for_topic(&self, topic: &str) -> &[PartitionInfo]

Get the list of partitions for this topic.

pub fn partition_count_for_topic(&self, topic: &str) -> Option<usize>

Get the number of partitions for the given topic.

pub fn available_partitions_for_topic(&self, topic: &str) -> &[PartitionInfo]

Get the list of available partitions for this topic.

pub fn partitions_for_node(&self, node_id: i32) -> &[PartitionInfo]

Get the list of partitions whose leader is this node.

pub fn topics(&self) -> impl Iterator<Item = &str>

Get all topics.

pub fn unauthorized_topics(&self) -> &HashSet<String>

Unauthorized topics.

pub fn invalid_topics(&self) -> &HashSet<String>

Invalid topics.

pub fn internal_topics(&self) -> &HashSet<String>

Internal topics.

pub fn is_bootstrap_configured(&self) -> bool

Whether bootstrap is configured.

pub fn cluster_resource(&self) -> &ClusterResource

The cluster resource metadata.

pub fn controller(&self) -> Option<&Node>

The controller node, if known.

pub fn topic_ids(&self) -> impl Iterator<Item = &Uuid>

All topic IDs.

pub fn topic_id(&self, topic: &str) -> Uuid

Get the topic ID for a given topic name.

pub fn topic_name(&self, topic_id: &Uuid) -> Option<&str>

Get the topic name for a given topic ID.