pub struct ClusterResource { /* private fields */ }Expand description
The ClusterResource class encapsulates metadata for a Kafka cluster.
Implementations
Sourceimpl ClusterResource
impl ClusterResource
Sourcepub fn new(cluster_id: Option<String>) -> Self
pub fn new(cluster_id: Option<String>) -> Self
Create a ClusterResource with a cluster id. Note that cluster id may be None if the
metadata request was sent to a broker without support for cluster ids.
Sourcepub fn cluster_id(&self) -> Option<&str>
pub fn cluster_id(&self) -> Option<&str>
Return the cluster id. Note that it may be None if the metadata request was sent to a
broker without support for cluster ids.