MetricName

Struct MetricName 

pub struct MetricName { /* private fields */ }
The MetricName class encapsulates a metric’s name, logical group and its related attributes. It should be constructed using Metrics::metric_name(...).

This class captures the following parameters:

  • name: The name of the metric
  • group: logical group name of the metrics to which this metric belongs.
  • description: A human-readable description to include in the metric. This is optional.
  • tags: additional key/value attributes of the metric. This is optional.

group and tags parameters can be used to create unique metric names while reporting in any custom reporting.

Two MetricNames are equal if their name, group, and tags match; description is intentionally excluded from equality and hashing, matching the Java implementation.

Implementations

Source

impl MetricName

pub fn new( name: impl Into<String>, group: impl Into<String>, description: impl Into<String>, tags: BTreeMap<String, String>, ) -> Self

Create a MetricName.

Please create MetricName via crate::common::metrics::Metrics::metric_name_description_tags.

  • name - The name of the metric
  • group - logical group name of the metrics to which this metric belongs
  • description - A human-readable description to include in the metric
  • tags - additional key/value attributes of the metric
pub fn name(&self) -> &str

The name of the metric.

pub fn group(&self) -> &str

The logical group name of the metrics to which this metric belongs.

pub fn tags(&self) -> &BTreeMap<String, String>

The additional key/value attributes of the metric.

pub fn description(&self) -> &str

A human-readable description of the metric.