MetricNameTemplate

Struct MetricNameTemplate 

pub struct MetricNameTemplate { /* private fields */ }
A template for a MetricName. It contains a name, group, and description, as well as all the tags that will be used to create the metric name. Tag values are omitted from the template, but are filled in at runtime with their specified values. The order of the tags is maintained so that the metric names can be compared and sorted lexicographically.

Implementations

Source

impl MetricNameTemplate

pub fn new( name: impl Into<String>, group: impl Into<String>, description: impl Into<String>, tag_names: IndexSet<String>, ) -> Self

Create a new template. The order of the tags is preserved.

  • name - the name of the metric
  • group - the name of the group
  • description - the description of the metric
  • tag_names - the names of the metric tags in the preferred order
pub fn name(&self) -> &str

Get the name of the metric.

pub fn group(&self) -> &str

Get the name of the group.

pub fn description(&self) -> &str

Get the description of the metric.

pub fn tags(&self) -> &IndexSet<String>

Get the ordered set of tag names for the metric.