Node

Struct Node 

pub struct Node { /* private fields */ }
Information about a Kafka node.

Implementations

Source

impl Node

pub fn new(id: i32, host: String, port: i32) -> Self

Creates a new Node with no rack and not fenced.

pub fn with_rack(id: i32, host: String, port: i32, rack: Option<String>) -> Self

Creates a new Node with the given rack.

pub fn with_rack_is_fenced( id: i32, host: String, port: i32, rack: Option<String>, is_fenced: bool, ) -> Self

Creates a new Node with the given rack and fenced status.

pub fn no_node() -> &'static Node

Returns a sentinel node representing no node.

pub fn is_empty(&self) -> bool

Check whether this node is empty, which may be the case if no_node() is used as a placeholder in a response payload with an error.

pub fn id(&self) -> i32

The node id of this node.

pub fn id_string(&self) -> &str

String representation of the node id. Typically the integer id is used to serialize over the wire, the string representation is used as an identifier with NetworkClient code.

pub fn host(&self) -> &str

The host name for this node.

pub fn port(&self) -> i32

The port for this node.

pub fn has_rack(&self) -> bool

True if this node has a defined rack.

pub fn rack(&self) -> Option<&str>

The rack for this node.

pub fn is_fenced(&self) -> bool

Returns whether this node is fenced.

This applies to broker nodes only. For controller quorum nodes, this field is not relevant and is defined to be false.