PartitionInfo

Struct PartitionInfo 

pub struct PartitionInfo { /* private fields */ }
This is used to describe per-partition state in the MetadataResponse.

Implementations

Source

impl PartitionInfo

pub fn new( topic: String, partition: i32, leader: Option<Node>, replicas: Vec<Node>, in_sync_replicas: Vec<Node>, ) -> Self

Creates a new PartitionInfo with no offline replicas.

pub fn with_offline_replicas( topic: String, partition: i32, leader: Option<Node>, replicas: Vec<Node>, in_sync_replicas: Vec<Node>, offline_replicas: Vec<Node>, ) -> Self

Creates a new PartitionInfo with offline replicas.

pub fn topic(&self) -> &str

The topic name.

pub fn partition(&self) -> i32

The partition id.

pub fn leader(&self) -> Option<&Node>

The node currently acting as a leader for this partition, or None if there is no leader.

pub fn replicas(&self) -> &[Node]

The complete set of replicas for this partition regardless of whether they are alive or up-to-date. The preferred replica is the head of the list.

pub fn in_sync_replicas(&self) -> &[Node]

The subset of the replicas that are in sync, that is caught-up to the leader and ready to take over as leader if the leader should fail.

pub fn offline_replicas(&self) -> &[Node]

The subset of the replicas that are offline.