TopicPartitionInfo

Struct TopicPartitionInfo 

pub struct TopicPartitionInfo { /* private fields */ }
A class containing leadership, replicas and ISR information for a topic partition.

Corresponds to org.apache.kafka.common.TopicPartitionInfo.

leader is None when there is no leader (Java null); elr and last_known_elr are None when the information is unavailable (the Java short constructor leaves them null).

Implementations

Source

impl TopicPartitionInfo

pub fn with_elr_last_known_elr( partition: i32, leader: Option<Node>, replicas: Vec<Node>, isr: Vec<Node>, elr: Vec<Node>, last_known_elr: Vec<Node>, ) -> Self

Create an instance with the provided parameters.

  • partition - the partition id
  • leader - the leader of the partition or None if there is none
  • replicas - the replicas of the partition in the same order as the replica assignment (the preferred replica is the head of the list)
  • isr - the in-sync replicas
  • elr - the eligible leader replicas
  • last_known_elr - the last known eligible leader replicas
pub fn new( partition: i32, leader: Option<Node>, replicas: Vec<Node>, isr: Vec<Node>, ) -> Self

Create an instance without eligible-leader-replica information (the Java four-argument constructor, which leaves elr/last_known_elr null).

pub fn partition(&self) -> i32

Return the partition id.

pub fn leader(&self) -> Option<&Node>

Return the leader of the partition or None if there is none.

pub fn replicas(&self) -> &[Node]

Return the replicas of the partition in the same order as the replica assignment. The preferred replica is the head of the list.

pub fn isr(&self) -> &[Node]

Return the in-sync replicas of the partition. The ordering is unspecified.

pub fn elr(&self) -> Option<&[Node]>

Return the eligible leader replicas of the partition, or None if unavailable. The ordering is unspecified.

pub fn last_known_elr(&self) -> Option<&[Node]>

Return the last known eligible leader replicas of the partition, or None if unavailable. The ordering is unspecified.