OffsetAndTimestamp

Struct OffsetAndTimestamp 

pub struct OffsetAndTimestamp { /* private fields */ }
A container class for offset and timestamp.

Corresponds to Java’s org.apache.kafka.clients.consumer.OffsetAndTimestamp.

offsets_for_times mapping note: this value is non-nullable, so when it is the value type of an offsets_for_times result map, an unresolved partition (queried but with no offset at/after the target time) is omitted from the map (key absent) rather than present with a null value as in Java. See Consumer::offsets_for_times.

Implementations

Source

impl OffsetAndTimestamp

pub fn new(offset: i64, timestamp: i64) -> Result<Self, Error>

Create a new OffsetAndTimestamp with no leader epoch.

Errors

Returns Error::LocalIllegalArgument if offset or timestamp is negative (matching Java’s IllegalArgumentException).

pub fn with_leader_epoch( offset: i64, timestamp: i64, leader_epoch: Option<i32>, ) -> Result<Self, Error>

Create a new OffsetAndTimestamp with an optional leader epoch.

Errors

Returns Error::LocalIllegalArgument if offset or timestamp is negative (matching Java’s IllegalArgumentException).

pub fn timestamp(&self) -> i64

The timestamp.

pub fn offset(&self) -> i64

The offset.

pub fn leader_epoch(&self) -> Option<i32>

Get the leader epoch corresponding to the offset that was found (if one exists). This can be provided to seek() to ensure the log hasn’t been truncated prior to fetching.