RecordMetadata

Struct RecordMetadata 

pub struct RecordMetadata { /* private fields */ }
The metadata for a record that has been acknowledged by the server.

Implementations

Source

impl RecordMetadata

pub const INVALID_OFFSET: i64 = -1

Value used when the offset is unknown (i.e., ProduceResponse.INVALID_OFFSET).

pub const UNKNOWN_PARTITION: i32 = -1

Partition value for record without partition assigned.

pub fn new( topic_partition: TopicPartition, base_offset: i64, batch_index: i32, timestamp: i64, serialized_key_size: i32, serialized_value_size: i32, ) -> Self

Creates a new instance with the provided parameters.

pub fn has_offset(&self) -> bool

Indicates whether the record metadata includes the offset.

pub fn offset(&self) -> i64

The offset of the record in the topic/partition. Returns -1 if has_offset() returns false.

pub fn has_timestamp(&self) -> bool

Indicates whether the record metadata includes the timestamp.

pub fn timestamp(&self) -> i64

The timestamp of the record in the topic/partition. Returns -1 if has_timestamp() returns false.

pub fn serialized_key_size(&self) -> i32

The size of the serialized, uncompressed key in bytes. Returns -1 if key is null.

pub fn serialized_value_size(&self) -> i32

The size of the serialized, uncompressed value in bytes. Returns -1 if value is null.

pub fn topic(&self) -> &str

The topic the record was appended to.

pub fn partition(&self) -> i32

The partition the record was sent to.

pub fn topic_partition(&self) -> &TopicPartition

The topic and partition the record was sent to.