pub struct Current<T>(/* private fields */);Expand description
The current value of a type.
Implementations
Sourceimpl<T> Current<T>where
T: Any,
impl<T> Current<T>where
T: Any,
Sourcepub unsafe fn current(&mut self) -> Option<&mut T>
pub unsafe fn current(&mut self) -> Option<&mut T>
Gets mutable reference to current object. Requires mutable reference to prevent access to globals in safe code, and to prevent mutable borrows of same value in scope. Is unsafe because returned reference inherits lifetime from argument.
Sourcepub unsafe fn current_unwrap(&mut self) -> &mut T
pub unsafe fn current_unwrap(&mut self) -> &mut T
Unwraps mutable reference to current object, but with nicer error message.