pub struct DescribeProducersResult { /* private fields */ }Expand description
The result of Admin::describe_producers.
Corresponds to org.apache.kafka.clients.admin.DescribeProducersResult.
Implementations
Sourceimpl DescribeProducersResult
impl DescribeProducersResult
Sourcepub fn partition_result(
&self,
partition: &TopicPartition,
) -> Result<KafkaFuture<PartitionProducerState>, Error>
pub fn partition_result( &self, partition: &TopicPartition, ) -> Result<KafkaFuture<PartitionProducerState>, Error>
Returns the future for a specific partition.
Mirrors DescribeProducersResult.partitionResult. Returns an error if
the partition was not included in the request, mirroring Java’s
IllegalArgumentException.
Errors
Returns Error::local_illegal_argument if partition was not requested.
Sourcepub fn all(
&self,
) -> KafkaFuture<HashMap<TopicPartition, PartitionProducerState>>
pub fn all( &self, ) -> KafkaFuture<HashMap<TopicPartition, PartitionProducerState>>
Returns a future yielding a map of every requested partition’s producer state. Fails if any partition’s request fails.
Mirrors DescribeProducersResult.all.