pub struct ReplicaLogDirInfo { /* private fields */ }Expand description
Log directory information for a replica of a partition on a given broker.
Corresponds to DescribeReplicaLogDirsResult.ReplicaLogDirInfo.
Implementations
Sourceimpl ReplicaLogDirInfo
impl ReplicaLogDirInfo
Sourcepub fn current_replica_log_dir(&self) -> Option<&str>
pub fn current_replica_log_dir(&self) -> Option<&str>
The current log directory of the replica of this partition on the given
broker. None if no replica is found for this partition on the broker.
Sourcepub fn current_replica_offset_lag(&self) -> i64
pub fn current_replica_offset_lag(&self) -> i64
Defined as max(HW of partition - LEO of the replica, 0).
Sourcepub fn future_replica_log_dir(&self) -> Option<&str>
pub fn future_replica_log_dir(&self) -> Option<&str>
The future log directory of the replica of this partition on the given
broker. None if the replica of this partition is not being moved to
another log directory on the given broker.
Sourcepub fn future_replica_offset_lag(&self) -> i64
pub fn future_replica_offset_lag(&self) -> i64
The LEO of the replica minus the LEO of the future log of this replica in
the destination log directory. -1 if either there is no replica for
this partition or the replica is not being moved to another log
directory on the given broker.