pub struct DescribeClusterOptions { /* private fields */ }Expand description
Options for Admin::describe_cluster.
Corresponds to org.apache.kafka.clients.admin.DescribeClusterOptions.
Implementations
Sourceimpl DescribeClusterOptions
impl DescribeClusterOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Set whether to include cluster authorized operations.
Whether to include cluster authorized operations.
Sourcepub fn set_include_fenced_brokers(self, include_fenced_brokers: bool) -> Self
pub fn set_include_fenced_brokers(self, include_fenced_brokers: bool) -> Self
Set whether to include fenced brokers when they are not fenced from the cluster (only supported by the broker endpoint at DescribeCluster v2+).
Sourcepub fn include_fenced_brokers(&self) -> bool
pub fn include_fenced_brokers(&self) -> bool
Whether to include fenced brokers.