pub struct DescribeConfigsOptions { /* private fields */ }Expand description
Options for Admin::describe_configs.
Corresponds to org.apache.kafka.clients.admin.DescribeConfigsOptions.
Implementations
Sourceimpl DescribeConfigsOptions
impl DescribeConfigsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn set_include_synonyms(self, include_synonyms: bool) -> Self
pub fn set_include_synonyms(self, include_synonyms: bool) -> Self
Set whether to return configuration synonyms in the response.
Sourcepub fn include_synonyms(&self) -> bool
pub fn include_synonyms(&self) -> bool
Whether to return configuration synonyms in the response.
Sourcepub fn set_include_documentation(self, include_documentation: bool) -> Self
pub fn set_include_documentation(self, include_documentation: bool) -> Self
Set whether to return configuration documentation in the response.
Sourcepub fn include_documentation(&self) -> bool
pub fn include_documentation(&self) -> bool
Whether to return configuration documentation in the response.