pub struct DescribeDelegationTokenOptions { /* private fields */ }Expand description
Options for Admin::describe_delegation_token.
Corresponds to
org.apache.kafka.clients.admin.DescribeDelegationTokenOptions.
Implementations
Sourceimpl DescribeDelegationTokenOptions
impl DescribeDelegationTokenOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (default API timeout, describe all authorized tokens).
Sourcepub fn set_owners(self, owners: Option<Vec<KafkaPrincipal>>) -> Self
pub fn set_owners(self, owners: Option<Vec<KafkaPrincipal>>) -> Self
Sets the owners to describe delegation tokens for.
If owners is None, all the user-owned tokens and tokens where the user
has Describe permission will be returned.
Mirrors DescribeDelegationTokenOptions.owners.
Sourcepub fn owners(&self) -> Option<&[KafkaPrincipal]>
pub fn owners(&self) -> Option<&[KafkaPrincipal]>
The owners to describe delegation tokens for, or None for all
authorized tokens.
Mirrors DescribeDelegationTokenOptions.owners.
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.