pub struct DescribeTopicsOptions { /* private fields */ }Expand description
Options for Admin::describe_topics_with_topics.
Corresponds to org.apache.kafka.clients.admin.DescribeTopicsOptions.
Implementations
Sourceimpl DescribeTopicsOptions
impl DescribeTopicsOptions
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Set whether to include authorized operations for the described topics.
Whether to include authorized operations for the described topics.
Sourcepub fn set_partition_size_limit_per_response(
self,
partition_size_limit_per_response: i32,
) -> Self
pub fn set_partition_size_limit_per_response( self, partition_size_limit_per_response: i32, ) -> Self
Sets the maximum number of partitions to be returned in a single
response. Only effective when using topic names (not topic IDs), and
capped by the server-side max.request.partition.size.limit.
Sourcepub fn partition_size_limit_per_response(&self) -> i32
pub fn partition_size_limit_per_response(&self) -> i32
The maximum number of partitions per response.