pub struct ListOffsetsOptions { /* private fields */ }Expand description
Options for Admin::list_offsets.
Corresponds to org.apache.kafka.clients.admin.ListOffsetsOptions, which
extends AbstractOptions (a timeout_ms field) and adds an isolation
level (defaulting to READ_UNCOMMITTED).
Implementations
Sourceimpl ListOffsetsOptions
impl ListOffsetsOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (default API timeout, READ_UNCOMMITTED).
Mirrors new ListOffsetsOptions().
Sourcepub fn with_isolation_level(isolation_level: IsolationLevel) -> Self
pub fn with_isolation_level(isolation_level: IsolationLevel) -> Self
Creates options with the given isolation level.
Mirrors new ListOffsetsOptions(IsolationLevel).
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.
Sourcepub fn isolation_level(&self) -> IsolationLevel
pub fn isolation_level(&self) -> IsolationLevel
The isolation level for this operation.
Mirrors isolationLevel().