pub struct RenewDelegationTokenOptions { /* private fields */ }Expand description
Options for Admin::renew_delegation_token.
Corresponds to
org.apache.kafka.clients.admin.RenewDelegationTokenOptions.
Implementations
Sourceimpl RenewDelegationTokenOptions
impl RenewDelegationTokenOptions
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates default options (default API timeout, server-default renew period).
Sourcepub fn set_renew_time_period_ms(self, renew_time_period_ms: i64) -> Self
pub fn set_renew_time_period_ms(self, renew_time_period_ms: i64) -> Self
Sets the renew time period in milliseconds.
Mirrors RenewDelegationTokenOptions.renewTimePeriodMs.
Sourcepub fn renew_time_period_ms(&self) -> i64
pub fn renew_time_period_ms(&self) -> i64
The renew time period in milliseconds.
Mirrors RenewDelegationTokenOptions.renewTimePeriodMs.
Sourcepub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
pub fn set_timeout_ms(self, timeout_ms: Option<i32>) -> Self
Set the timeout in milliseconds for this operation, or None to use the
default API timeout for the AdminClient.
Sourcepub fn timeout_ms(&self) -> Option<i32>
pub fn timeout_ms(&self) -> Option<i32>
The timeout in milliseconds for this operation, or None if the default
API timeout should be used.