pub struct Config { /* private fields */ }Expand description
A configuration object containing the configuration entries for a resource.
Corresponds to org.apache.kafka.clients.admin.Config.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn new(entries: impl IntoIterator<Item = ConfigEntry>) -> Self
pub fn new(entries: impl IntoIterator<Item = ConfigEntry>) -> Self
Create a configuration instance with the provided entries.
Sourcepub fn entries(&self) -> impl Iterator<Item = &ConfigEntry>
pub fn entries(&self) -> impl Iterator<Item = &ConfigEntry>
Configuration entries for a resource.
Sourcepub fn get(&self, name: &str) -> Option<&ConfigEntry>
pub fn get(&self, name: &str) -> Option<&ConfigEntry>
Get the configuration entry with the provided name or None if there
isn’t one.