pub struct DeletedRecords { /* private fields */ }Expand description
Represents information about deleted records.
Corresponds to org.apache.kafka.clients.admin.DeletedRecords.
Implementations
Sourceimpl DeletedRecords
impl DeletedRecords
Sourcepub fn new(low_watermark: i64) -> Self
pub fn new(low_watermark: i64) -> Self
Create an instance of this class with the provided parameters.
low_watermark is the “low watermark” for the topic partition on which
the deletion was executed.
Sourcepub fn low_watermark(&self) -> i64
pub fn low_watermark(&self) -> i64
Return the “low watermark” for the topic partition on which the deletion was executed.