pub struct DescribeClusterResult { /* private fields */ }Expand description
The result of the Admin::describe_cluster call.
Corresponds to org.apache.kafka.clients.admin.DescribeClusterResult.
Implementations
Sourceimpl DescribeClusterResult
impl DescribeClusterResult
Sourcepub fn nodes(&self) -> KafkaFuture<Vec<Node>>
pub fn nodes(&self) -> KafkaFuture<Vec<Node>>
Returns a future which yields a collection of nodes in the cluster.
Sourcepub fn controller(&self) -> KafkaFuture<Option<Node>>
pub fn controller(&self) -> KafkaFuture<Option<Node>>
Returns a future which yields the current controller node in the cluster.
The value is None if there is no current controller.
Sourcepub fn cluster_id(&self) -> KafkaFuture<String>
pub fn cluster_id(&self) -> KafkaFuture<String>
Returns a future which yields the id of the cluster.
Returns a future which yields the authorized operations of the cluster.
The value is None if the operations were not requested or the broker
omitted them.