pub struct FeatureMetadata { /* private fields */ }Expand description
Encapsulates details about finalized as well as supported features.
This is particularly useful to hold the result returned by the
describe_features_with_options API.
Corresponds to org.apache.kafka.clients.admin.FeatureMetadata.
Implementations
Sourceimpl FeatureMetadata
impl FeatureMetadata
Sourcepub fn finalized_features(&self) -> &HashMap<String, FinalizedVersionRange>
pub fn finalized_features(&self) -> &HashMap<String, FinalizedVersionRange>
Returns a map of finalized feature versions. Each entry contains a feature name and the range of version levels supported by every broker in the cluster.
Sourcepub fn finalized_features_epoch(&self) -> Option<i64>
pub fn finalized_features_epoch(&self) -> Option<i64>
The epoch for the finalized features. If empty, the finalized features are absent/unavailable.
Sourcepub fn supported_features(&self) -> &HashMap<String, SupportedVersionRange>
pub fn supported_features(&self) -> &HashMap<String, SupportedVersionRange>
Returns a map of supported feature versions. Each entry contains a feature name and the range of versions supported by a particular broker in the cluster.