pub struct ListConsumerGroupOffsetsSpec { /* private fields */ }Expand description
Specification of consumer group offsets to list using
Admin::list_consumer_group_offsets_with_group_specs.
Corresponds to org.apache.kafka.clients.admin.ListConsumerGroupOffsetsSpec.
topic_partitions == None includes all topic partitions of the group.
Implementations
Sourceimpl ListConsumerGroupOffsetsSpec
impl ListConsumerGroupOffsetsSpec
Sourcepub fn set_topic_partitions(
self,
topic_partitions: Option<Vec<TopicPartition>>,
) -> Self
pub fn set_topic_partitions( self, topic_partitions: Option<Vec<TopicPartition>>, ) -> Self
Set the topic partitions whose offsets are to be listed for a consumer
group. None includes all topic partitions.
Mirrors topicPartitions(Collection<TopicPartition>).
Sourcepub fn topic_partitions(&self) -> Option<&[TopicPartition]>
pub fn topic_partitions(&self) -> Option<&[TopicPartition]>
Returns the topic partitions whose offsets are to be listed for a
consumer group. None indicates that offsets of all partitions of the
group are to be listed.
Mirrors topicPartitions().