pub struct RecordsToDelete { /* private fields */ }Expand description
Describe records to delete in a call to Admin::delete_records.
Corresponds to org.apache.kafka.clients.admin.RecordsToDelete.
Implementations
Sourceimpl RecordsToDelete
impl RecordsToDelete
Sourcepub fn before_offset_with_offset(offset: i64) -> Self
pub fn before_offset_with_offset(offset: i64) -> Self
Delete all the records before the given offset.
Use -1 to truncate to the high watermark.
Java’s static beforeOffset(long) shares its name with the getter
before_offset, so it takes the _with_offset
suffix of its parameter (CLAUDE.md 2).
Sourcepub fn before_offset(&self) -> i64
pub fn before_offset(&self) -> i64
The offset before which all records will be deleted.
Use -1 to truncate to the high watermark.