pub struct RemoveMembersFromConsumerGroupResult { /* private fields */ }Expand description
The result of Admin::remove_members_from_consumer_group.
Corresponds to
org.apache.kafka.clients.admin.RemoveMembersFromConsumerGroupResult.
Implementations
Sourceimpl RemoveMembersFromConsumerGroupResult
impl RemoveMembersFromConsumerGroupResult
Sourcepub fn all(&self) -> KafkaFuture<()>
pub fn all(&self) -> KafkaFuture<()>
Returns a future which indicates whether the request was 100% successful (no top-level or member-level error); otherwise the first member error is returned.
Mirrors all().
Sourcepub fn member_result(
&self,
member: &MemberToRemove,
) -> Result<KafkaFuture<()>, Error>
pub fn member_result( &self, member: &MemberToRemove, ) -> Result<KafkaFuture<()>, Error>
Returns the selected member’s future.
Mirrors memberResult(MemberToRemove).
Errors
Returns an error immediately (Java’s IllegalArgumentException) when
called in removeAll mode, or when member was not part of the original
request. The returned future fails if the member’s removal failed (or the
member is missing from the response).