pub struct ReplicaInfo { /* private fields */ }Expand description
A description of a replica on a particular broker.
Corresponds to org.apache.kafka.clients.admin.ReplicaInfo.
Implementations
Sourceimpl ReplicaInfo
impl ReplicaInfo
Sourcepub fn size(&self) -> i64
pub fn size(&self) -> i64
The total size of the log segments in this replica in bytes.
This value does not include the size of data stored in remote storage.
Sourcepub fn offset_lag(&self) -> i64
pub fn offset_lag(&self) -> i64
The lag of the log’s LEO with respect to the partition’s high watermark (if it is the current log for the partition) or the current replica’s LEO (if it is the future log for the partition).