pub struct TransactionDescription { /* private fields */ }Expand description
The description of a transaction.
Corresponds to org.apache.kafka.clients.admin.TransactionDescription.
producer_id and transaction_timeout_ms are i64 (Java long);
coordinator_id and producer_epoch are i32 (Java int);
transaction_start_time_ms is optional (Java OptionalLong).
Implementations
Sourceimpl TransactionDescription
impl TransactionDescription
Sourcepub fn new(
coordinator_id: i32,
state: TransactionState,
producer_id: i64,
producer_epoch: i32,
transaction_timeout_ms: i64,
transaction_start_time_ms: Option<i64>,
topic_partitions: HashSet<TopicPartition>,
) -> Self
pub fn new( coordinator_id: i32, state: TransactionState, producer_id: i64, producer_epoch: i32, transaction_timeout_ms: i64, transaction_start_time_ms: Option<i64>, topic_partitions: HashSet<TopicPartition>, ) -> Self
Creates a new TransactionDescription.
Sourcepub fn coordinator_id(&self) -> i32
pub fn coordinator_id(&self) -> i32
The id of the coordinator that owns this transaction.
Sourcepub fn state(&self) -> TransactionState
pub fn state(&self) -> TransactionState
The current state of the transaction.
Sourcepub fn producer_id(&self) -> i64
pub fn producer_id(&self) -> i64
The producer id of the transaction.
Sourcepub fn producer_epoch(&self) -> i32
pub fn producer_epoch(&self) -> i32
The producer epoch of the transaction.
Sourcepub fn transaction_timeout_ms(&self) -> i64
pub fn transaction_timeout_ms(&self) -> i64
The transaction timeout in milliseconds.
Sourcepub fn transaction_start_time_ms(&self) -> Option<i64>
pub fn transaction_start_time_ms(&self) -> Option<i64>
The transaction start time in milliseconds, if a transaction is in progress.
Sourcepub fn topic_partitions(&self) -> &HashSet<TopicPartition>
pub fn topic_partitions(&self) -> &HashSet<TopicPartition>
The set of topic partitions that have been added to the transaction.