pub struct AclBinding { /* private fields */ }Expand description
Represents a binding between a resource pattern and an access control entry.
Corresponds to org.apache.kafka.common.acl.AclBinding.
Implementations
Sourceimpl AclBinding
impl AclBinding
Sourcepub fn new(pattern: ResourcePattern, entry: AccessControlEntry) -> AclBinding
pub fn new(pattern: ResourcePattern, entry: AccessControlEntry) -> AclBinding
Create an instance of this class with the provided parameters.
Arguments
pattern- resource patternentry- entry
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Return true if this binding has any UNKNOWN components.
Sourcepub fn pattern(&self) -> &ResourcePattern
pub fn pattern(&self) -> &ResourcePattern
Return the resource pattern for this binding.
Sourcepub fn entry(&self) -> &AccessControlEntry
pub fn entry(&self) -> &AccessControlEntry
Return the access control entry for this binding.
Sourcepub fn to_filter(&self) -> AclBindingFilter
pub fn to_filter(&self) -> AclBindingFilter
Create a filter which matches only this AclBinding.