pub struct Meter { /* private fields */ }Expand description
A compound stat that includes a rate metric and a cumulative total metric.
Implementations
Sourceimpl Meter
impl Meter
Sourcepub fn new(rate_metric_name: MetricName, total_metric_name: MetricName) -> Self
pub fn new(rate_metric_name: MetricName, total_metric_name: MetricName) -> Self
Construct a Meter with seconds as time unit, backed by a WindowedSum.
Sourcepub fn with_unit(
unit: TimeUnit,
rate_metric_name: MetricName,
total_metric_name: MetricName,
) -> Self
pub fn with_unit( unit: TimeUnit, rate_metric_name: MetricName, total_metric_name: MetricName, ) -> Self
Construct a Meter with the provided time unit, backed by a WindowedSum.
Sourcepub fn with_rate_stat(
rate_stat: Arc<SampledStat>,
rate_metric_name: MetricName,
total_metric_name: MetricName,
) -> Self
pub fn with_rate_stat( rate_stat: Arc<SampledStat>, rate_metric_name: MetricName, total_metric_name: MetricName, ) -> Self
Construct a Meter with seconds as time unit and a provided rate stat.
Sourcepub fn with_unit_rate_stat(
unit: TimeUnit,
rate_stat: Arc<SampledStat>,
rate_metric_name: MetricName,
total_metric_name: MetricName,
) -> Self
pub fn with_unit_rate_stat( unit: TimeUnit, rate_stat: Arc<SampledStat>, rate_metric_name: MetricName, total_metric_name: MetricName, ) -> Self
Construct a Meter with the provided time unit and rate stat.
Panics if rate_stat is not a WindowedSum/WindowedCount, mirroring
Java’s IllegalArgumentException — this is a construction-time
programming error (Meter is only meaningful with a windowed sum/count).