pub trait CompoundStat: Stat {
// Required method
fn stats(&self) -> Vec<NamedMeasurable>;
}Expand description
A compound stat is a stat where a single measurement and associated data structure feeds many metrics. This is the example for a histogram which has many associated percentiles.
Required Methods
Sourcefn stats(&self) -> Vec<NamedMeasurable>
fn stats(&self) -> Vec<NamedMeasurable>
The named measurable child metrics this compound stat exposes.