pub struct ClientQuotaEntity { /* private fields */ }Expand description
Describes a client quota entity, which is a mapping of entity types to their names.
Corresponds to org.apache.kafka.common.quota.ClientQuotaEntity.
Java models the mapping as a Map<String, String> whose values may be
null: “If a name is null, then it is mapped to the built-in default entity
name” (e.g. --entity-type users --entity-default). Rust cannot store a
null String, so the faithful representation of Java’s nullable map value
is Option<String>: None is the built-in default entity (wire-null entity
name), and Some(name) is a concretely-named entity (Some(String::new())
is the entity literally named "", which is distinct from the default).
Implementations
Sourceimpl ClientQuotaEntity
impl ClientQuotaEntity
Sourcepub fn is_valid_entity_type(entity_type: &str) -> bool
pub fn is_valid_entity_type(entity_type: &str) -> bool
Returns whether the given entity type is one of the built-in types.
Mirrors ClientQuotaEntity.isValidEntityType.