pub struct ResourcePattern { /* private fields */ }Expand description
Represents a pattern that is used by ACLs to match zero or more
Resources.
Corresponds to org.apache.kafka.common.resource.ResourcePattern.
Implementations
Sourceimpl ResourcePattern
impl ResourcePattern
Sourcepub const WILDCARD_RESOURCE: &str = "*"
pub const WILDCARD_RESOURCE: &str = "*"
A special literal resource name that corresponds to ‘all resources of a certain type’.
Sourcepub fn new(
resource_type: ResourceType,
name: impl Into<String>,
pattern_type: PatternType,
) -> Result<ResourcePattern, Error>
pub fn new( resource_type: ResourceType, name: impl Into<String>, pattern_type: PatternType, ) -> Result<ResourcePattern, Error>
Create a pattern using the supplied parameters.
Arguments
resource_type- specific resource typename- resource name, which can be theSelf::WILDCARD_RESOURCEpattern_type- specific resource pattern type, which controls how the pattern will match resource names
Errors
Returns Error::LocalIllegalArgument if resource_type is
ResourceType::Any, or pattern_type is PatternType::Match or
PatternType::Any (mirrors Java’s IllegalArgumentException).
Sourcepub fn resource_type(&self) -> ResourceType
pub fn resource_type(&self) -> ResourceType
Return the specific resource type this pattern matches.
Sourcepub fn pattern_type(&self) -> PatternType
pub fn pattern_type(&self) -> PatternType
Return the resource pattern type.
Sourcepub fn to_filter(&self) -> ResourcePatternFilter
pub fn to_filter(&self) -> ResourcePatternFilter
Return a filter which matches only this pattern.
Sourcepub fn is_unknown(&self) -> bool
pub fn is_unknown(&self) -> bool
Return true if this pattern has any UNKNOWN components.