pub struct MetricNameTemplate { /* private fields */ }Expand description
A template for a MetricName. It contains a name, group, and description, as
well as all the tags that will be used to create the metric name. Tag values
are omitted from the template, but are filled in at runtime with their
specified values. The order of the tags is maintained so that the metric
names can be compared and sorted lexicographically.
Implementations
Sourceimpl MetricNameTemplate
impl MetricNameTemplate
Sourcepub fn new(
name: impl Into<String>,
group: impl Into<String>,
description: impl Into<String>,
tag_names: IndexSet<String>,
) -> Self
pub fn new( name: impl Into<String>, group: impl Into<String>, description: impl Into<String>, tag_names: IndexSet<String>, ) -> Self
Create a new template. The order of the tags is preserved.
name- the name of the metricgroup- the name of the groupdescription- the description of the metrictag_names- the names of the metric tags in the preferred order
Sourcepub fn description(&self) -> &str
pub fn description(&self) -> &str
Get the description of the metric.
Get the ordered set of tag names for the metric.