pub struct Node { /* private fields */ }Expand description
Information about a Kafka node.
Implementations
Sourceimpl Node
impl Node
Sourcepub fn new(id: i32, host: String, port: i32) -> Self
pub fn new(id: i32, host: String, port: i32) -> Self
Creates a new Node with no rack and not fenced.
Sourcepub fn with_rack(id: i32, host: String, port: i32, rack: Option<String>) -> Self
pub fn with_rack(id: i32, host: String, port: i32, rack: Option<String>) -> Self
Creates a new Node with the given rack.
Sourcepub fn with_rack_is_fenced(
id: i32,
host: String,
port: i32,
rack: Option<String>,
is_fenced: bool,
) -> Self
pub fn with_rack_is_fenced( id: i32, host: String, port: i32, rack: Option<String>, is_fenced: bool, ) -> Self
Creates a new Node with the given rack and fenced status.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Check whether this node is empty, which may be the case if no_node() is used
as a placeholder in a response payload with an error.