pub struct PartitionInfo { /* private fields */ }Expand description
This is used to describe per-partition state in the MetadataResponse.
Implementations
Sourceimpl PartitionInfo
impl PartitionInfo
Sourcepub fn new(
topic: String,
partition: i32,
leader: Option<Node>,
replicas: Vec<Node>,
in_sync_replicas: Vec<Node>,
) -> Self
pub fn new( topic: String, partition: i32, leader: Option<Node>, replicas: Vec<Node>, in_sync_replicas: Vec<Node>, ) -> Self
Creates a new PartitionInfo with no offline replicas.
Sourcepub fn with_offline_replicas(
topic: String,
partition: i32,
leader: Option<Node>,
replicas: Vec<Node>,
in_sync_replicas: Vec<Node>,
offline_replicas: Vec<Node>,
) -> Self
pub fn with_offline_replicas( topic: String, partition: i32, leader: Option<Node>, replicas: Vec<Node>, in_sync_replicas: Vec<Node>, offline_replicas: Vec<Node>, ) -> Self
Creates a new PartitionInfo with offline replicas.
Sourcepub fn leader(&self) -> Option<&Node>
pub fn leader(&self) -> Option<&Node>
The node currently acting as a leader for this partition, or None if there is no leader.
Sourcepub fn replicas(&self) -> &[Node]
pub fn replicas(&self) -> &[Node]
The complete set of replicas for this partition regardless of whether they are alive or up-to-date. The preferred replica is the head of the list.
Sourcepub fn in_sync_replicas(&self) -> &[Node]
pub fn in_sync_replicas(&self) -> &[Node]
The subset of the replicas that are in sync, that is caught-up to the leader and ready to take over as leader if the leader should fail.
Sourcepub fn offline_replicas(&self) -> &[Node]
pub fn offline_replicas(&self) -> &[Node]
The subset of the replicas that are offline.