pub struct OffsetAndMetadata { /* private fields */ }Expand description
The Kafka offset commit API allows users to provide additional metadata (in the form of a string) when an offset is committed. This can be useful (for example) to store information about which node made the commit, what time the commit was made, etc.
Corresponds to Java’s org.apache.kafka.clients.consumer.OffsetAndMetadata.
Implementations
Sourceimpl OffsetAndMetadata
impl OffsetAndMetadata
Sourcepub fn new(offset: i64) -> Result<Self, Error>
pub fn new(offset: i64) -> Result<Self, Error>
Construct a new OffsetAndMetadata with the given offset.
The metadata is set to the empty string and no leader epoch is set.
Corresponds to Java’s new OffsetAndMetadata(long offset).
Errors
Returns Error::LocalIllegalArgument if offset is negative
(matching Java’s IllegalArgumentException).
Sourcepub fn with_metadata(
offset: i64,
metadata: impl Into<String>,
) -> Result<Self, Error>
pub fn with_metadata( offset: i64, metadata: impl Into<String>, ) -> Result<Self, Error>
Construct a new OffsetAndMetadata with the given offset and metadata.
Corresponds to Java’s new OffsetAndMetadata(long offset, String metadata).
Errors
Returns Error::LocalIllegalArgument if offset is negative.
Sourcepub fn with_leader_epoch_metadata(
offset: i64,
leader_epoch: Option<i32>,
metadata: impl Into<String>,
) -> Result<Self, Error>
pub fn with_leader_epoch_metadata( offset: i64, leader_epoch: Option<i32>, metadata: impl Into<String>, ) -> Result<Self, Error>
Construct a new OffsetAndMetadata with offset, optional leader epoch,
and metadata.
Corresponds to Java’s
new OffsetAndMetadata(long, Optional<Integer>, String).
Errors
Returns Error::LocalIllegalArgument if offset is negative.
Sourcepub fn metadata(&self) -> &str
pub fn metadata(&self) -> &str
Returns the metadata associated with the commit, or an empty string if no metadata was provided.
Sourcepub fn leader_epoch(&self) -> Option<i32>
pub fn leader_epoch(&self) -> Option<i32>
Get the leader epoch of the previously consumed record (if one is
known). Negative epochs are filtered to None to match Java’s
leaderEpoch().